@@ -103,11 +103,12 @@ static A68G_INFO info_text[] = {
   {"options", "--preludelisting", "make a listing of preludes"},
   {"options", "--pretty-print", "pretty-print the source file"},
   {"options", "--print unit", "print value yielded by algol 68 unit \"unit\""},
-  {"options", "--quiet", "suppresses all warning diagnostics"},
+  {"options", "--quiet", "suppresses warning and notice diagnostics"},
   {"options", "--quotestropping", "set stropping mode to quote stropping"},
   {"options", "--reductions", "print parser reductions"},
   {"options", "--run", "override --check/--norun options"},
   {"options", "--rerun", "run using already compiled code"},
+  {"options", "--restart, --no-restart", "restart system calls at time limit check [--restart]"},
   {"options", "--script", "set next option as source file name; pass further options to algol 68 program"},
   {"options", "--source, --nosource", "switch listing of source lines in listing file on or off [--source]"},
   {"options", "--stack \"number\"", "set expression stack size to \"number\""},
