@@ -117,7 +117,7 @@ void pretty_diag (FILE_T f, char *p)
 
 void abend (char *reason, char *info, char *func)
 {
-  #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+  #if defined (BUILD_WINDOWS)
     printf_s ("%s: abend: %s.\n", A68G (a68g_cmd_name), reason);
   #else
     if (func == NO_TEXT) {
