@@ -81,7 +81,7 @@
 #include "a68g-prelude.h"
 #include "a68g-prelude-mathlib.h"
 
-#if defined (HAVE_MATHLIB)
+#if defined (HAVE_R_MATHLIB)
   #include <Rmath.h>
 #endif
 
@@ -194,7 +194,7 @@ void state_version (FILE_T f)
     ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With GNU MPFR %s\n", mpfr_get_version ()) >= 0);
     WRITE (f, A68G (output_line));
   #endif
-  #if defined (HAVE_MATHLIB)
+  #if defined (HAVE_R_MATHLIB)
     ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "With mathlib from R %s\n", R_VERSION_STRING) >= 0);
     WRITE (f, A68G (output_line));
   #endif
@@ -620,7 +620,7 @@ int main (int argc, char *argv[])
   A68G (close_tty_on_exit) = A68G_TRUE;
   FILE_DIAGS_FD (&A68G_JOB) = A68G_NO_FILE;
 // Get command name and discard path.
-  #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+  #if defined (BUILD_WINDOWS)
     a68g_bufcpy (A68G (a68g_cmd_name), "a68g", BUFFER_SIZE);
   #else
     a68g_bufcpy (A68G (a68g_cmd_name), argv[0], BUFFER_SIZE);
