@@ -25,10 +25,10 @@
 
 // An A68G row is a reference to a descriptor in the heap:
 //
-// A68_REF row -> A68_ARRAY ----+   ARRAY: Description of row, ref to elements.
-//                A68_TUPLE 1   |   TUPLE: Bounds, one for every dimension.
+// A68G_REF row -> A68G_ARRAY ----+   ARRAY: Description of row, ref to elements.
+//                A68G_TUPLE 1   |   TUPLE: Bounds, one for every dimension.
 //                ...           |
-//                A68_TUPLE dim |
+//                A68G_TUPLE dim |
 //                ...           |
 //                ...           |
 //                Element 1 <---+   Sequential row elements in the heap.
@@ -45,95 +45,95 @@
 
 void genie_monad_elems (NODE_T * p)
 {
-  A68_REF row;
+  A68G_REF row;
   POP_REF (p, &row);
-  DECREMENT_STACK_POINTER (p, A68_UNION_SIZE); // Pop UNION.
+  DECREMENT_STACK_POINTER (p, A68G_UNION_SIZE); // Pop UNION.
   CHECK_REF (p, row, M_ROWS);
-  A68_ARRAY *arr; A68_TUPLE *tup;
+  A68G_ARRAY *arr; A68G_TUPLE *tup;
   GET_DESCRIPTOR (arr, tup, &row);
-  PUSH_VALUE (p, get_row_size (tup, DIM (arr)), A68_INT);
+  PUSH_VALUE (p, get_row_size (tup, DIM (arr)), A68G_INT);
 }
 
 //! @brief OP LWB = (ROWS) INT
 
 void genie_monad_lwb (NODE_T * p)
 {
-  A68_REF row;
+  A68G_REF row;
   POP_REF (p, &row);
-  DECREMENT_STACK_POINTER (p, A68_UNION_SIZE); // Pop UNION.
+  DECREMENT_STACK_POINTER (p, A68G_UNION_SIZE); // Pop UNION.
   CHECK_REF (p, row, M_ROWS);
-  A68_ARRAY *arr; A68_TUPLE *tup;
+  A68G_ARRAY *arr; A68G_TUPLE *tup;
   GET_DESCRIPTOR (arr, tup, &row);
-  PUSH_VALUE (p, LWB (tup), A68_INT);
+  PUSH_VALUE (p, LWB (tup), A68G_INT);
 }
 
 //! @brief OP UPB = (ROWS) INT
 
 void genie_monad_upb (NODE_T * p)
 {
-  A68_REF row;
+  A68G_REF row;
   POP_REF (p, &row);
-  DECREMENT_STACK_POINTER (p, A68_UNION_SIZE); // Pop UNION.
+  DECREMENT_STACK_POINTER (p, A68G_UNION_SIZE); // Pop UNION.
   CHECK_REF (p, row, M_ROWS);
-  A68_ARRAY *arr; A68_TUPLE *tup;
+  A68G_ARRAY *arr; A68G_TUPLE *tup;
   GET_DESCRIPTOR (arr, tup, &row);
-  PUSH_VALUE (p, UPB (tup), A68_INT);
+  PUSH_VALUE (p, UPB (tup), A68G_INT);
 }
 
 //! @brief OP ELEMS = (INT, ROWS) INT
 
 void genie_dyad_elems (NODE_T * p)
 {
-  A68_REF row;
+  A68G_REF row;
   POP_REF (p, &row);
-  DECREMENT_STACK_POINTER (p, A68_UNION_SIZE); // Pop UNION.
+  DECREMENT_STACK_POINTER (p, A68G_UNION_SIZE); // Pop UNION.
   CHECK_REF (p, row, M_ROWS);
-  A68_INT k;
-  POP_OBJECT (p, &k, A68_INT);
-  A68_ARRAY *arr; A68_TUPLE *tup;
+  A68G_INT k;
+  POP_OBJECT (p, &k, A68G_INT);
+  A68G_ARRAY *arr; A68G_TUPLE *tup;
   GET_DESCRIPTOR (arr, tup, &row);
   if (VALUE (&k) < 1 || VALUE (&k) > DIM (arr)) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_INVALID_DIMENSION, (int) VALUE (&k));
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_DIMENSION, (int) VALUE (&k));
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
-  A68_TUPLE *u = &(tup[VALUE (&k) - 1]);
-  PUSH_VALUE (p, ROW_SIZE (u), A68_INT);
+  A68G_TUPLE *u = &(tup[VALUE (&k) - 1]);
+  PUSH_VALUE (p, ROW_SIZE (u), A68G_INT);
 }
 
 //! @brief OP LWB = (INT, ROWS) INT
 
 void genie_dyad_lwb (NODE_T * p)
 {
-  A68_REF row;
+  A68G_REF row;
   POP_REF (p, &row);
-  DECREMENT_STACK_POINTER (p, A68_UNION_SIZE); // Pop UNION.
+  DECREMENT_STACK_POINTER (p, A68G_UNION_SIZE); // Pop UNION.
   CHECK_REF (p, row, M_ROWS);
-  A68_INT k;
-  POP_OBJECT (p, &k, A68_INT);
-  A68_ARRAY *arr; A68_TUPLE *tup;
+  A68G_INT k;
+  POP_OBJECT (p, &k, A68G_INT);
+  A68G_ARRAY *arr; A68G_TUPLE *tup;
   GET_DESCRIPTOR (arr, tup, &row);
   if (VALUE (&k) < 1 || VALUE (&k) > DIM (arr)) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_INVALID_DIMENSION, (int) VALUE (&k));
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_DIMENSION, (int) VALUE (&k));
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
-  PUSH_VALUE (p, LWB (&(tup[VALUE (&k) - 1])), A68_INT);
+  PUSH_VALUE (p, LWB (&(tup[VALUE (&k) - 1])), A68G_INT);
 }
 
 //! @brief OP UPB = (INT, ROWS) INT
 
 void genie_dyad_upb (NODE_T * p)
 {
-  A68_REF row;
+  A68G_REF row;
   POP_REF (p, &row);
-  DECREMENT_STACK_POINTER (p, A68_UNION_SIZE); // Pop UNION.
+  DECREMENT_STACK_POINTER (p, A68G_UNION_SIZE); // Pop UNION.
   CHECK_REF (p, row, M_ROWS);
-  A68_INT k;
-  POP_OBJECT (p, &k, A68_INT);
-  A68_ARRAY *arr; A68_TUPLE *tup;
+  A68G_INT k;
+  POP_OBJECT (p, &k, A68G_INT);
+  A68G_ARRAY *arr; A68G_TUPLE *tup;
   GET_DESCRIPTOR (arr, tup, &row);
   if (VALUE (&k) < 1 || VALUE (&k) > DIM (arr)) {
-    diagnostic (A68_RUNTIME_ERROR, p, ERROR_INVALID_DIMENSION, (int) VALUE (&k));
-    exit_genie (p, A68_RUNTIME_ERROR);
+    diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_DIMENSION, (int) VALUE (&k));
+    exit_genie (p, A68G_RUNTIME_ERROR);
   }
-  PUSH_VALUE (p, UPB (&(tup[VALUE (&k) - 1])), A68_INT);
+  PUSH_VALUE (p, UPB (&(tup[VALUE (&k) - 1])), A68G_INT);
 }
