@@ -43,7 +43,7 @@
 // would not be worth the while.
 // Hence in recent a68c versions, LONG BITS is a 128-bit quad word,
 // and LONG LONG BITS is mapped onto LONG BITS.
-// Below code is left in a68g for reference purposes, and in case a build of
+// Below code is left in a68g for reference purposes, or when a build of
 // a version < 3 would be required.
 
 #define MP_BITS_WIDTH(k) ((int) ceil ((k) * LOG_MP_RADIX * CONST_LOG2_10) - 1)
@@ -269,7 +269,7 @@ void genie_lengthen_unt_to_mp (NODE_T * p)
 void genie_bin_mp (NODE_T * p)
 {
   MOID_T *mode = SUB_MOID (p);
-  int size = SIZE (mode);
+  size_t size = SIZE (mode);
   ADDR_T pop_sp = A68G_SP;
   MP_T *u = (MP_T *) STACK_OFFSET (-size);
 // We convert just for the operand check.
@@ -283,7 +283,7 @@ void genie_bin_mp (NODE_T * p)
 void genie_not_mp (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
-  int size = SIZE (mode);
+  size_t size = SIZE (mode);
   ADDR_T pop_sp = A68G_SP;
   int words = get_mp_bits_words (mode);
   MP_T *u = (MP_T *) STACK_OFFSET (-size);
@@ -432,7 +432,7 @@ void genie_long_bits_pack (NODE_T * p)
   CHECK_REF (p, z, M_ROW_BOOL);
   A68G_ARRAY *arr; A68G_TUPLE *tup;
   GET_DESCRIPTOR (arr, tup, &z);
-  int size = ROW_SIZE (tup);
+  size_t size = ROW_SIZE (tup);
   MOID_T *mode = MOID (p);
   int bits = get_mp_bits_width (mode);
   int digits = DIGITS (mode);
@@ -464,7 +464,7 @@ void genie_shl_mp (NODE_T * p)
   A68G_INT j;
   POP_OBJECT (p, &j, A68G_INT);
   MOID_T *mode = LHS_MODE (p);
-  int size = SIZE (mode), words = get_mp_bits_words (mode);
+  size_t size = SIZE (mode), words = get_mp_bits_words (mode);
   MP_T *u = (MP_T *) STACK_OFFSET (-size);
   ADDR_T pop_sp = A68G_SP;
   MP_BITS_T *row_u = stack_mp_bits (p, u, mode);
@@ -511,7 +511,7 @@ void genie_shr_mp (NODE_T * p)
 void genie_le_long_bits (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
-  int size = SIZE (mode), words = get_mp_bits_words (mode);
+  size_t size = SIZE (mode), words = get_mp_bits_words (mode);
   ADDR_T pop_sp = A68G_SP;
   MP_T *u = (MP_T *) STACK_OFFSET (-2 * size), *v = (MP_T *) STACK_OFFSET (-size);
   MP_BITS_T *row_u = stack_mp_bits (p, u, mode), *row_v = stack_mp_bits (p, v, mode);
@@ -529,7 +529,7 @@ void genie_le_long_bits (NODE_T * p)
 void genie_ge_long_bits (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
-  int size = SIZE (mode), words = get_mp_bits_words (mode);
+  size_t size = SIZE (mode), words = get_mp_bits_words (mode);
   ADDR_T pop_sp = A68G_SP;
   MP_T *u = (MP_T *) STACK_OFFSET (-2 * size), *v = (MP_T *) STACK_OFFSET (-size);
   MP_BITS_T *row_u = stack_mp_bits (p, u, mode), *row_v = stack_mp_bits (p, v, mode);
@@ -547,7 +547,7 @@ void genie_ge_long_bits (NODE_T * p)
 void genie_and_mp (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
-  int size = SIZE (mode), words = get_mp_bits_words (mode);
+  size_t size = SIZE (mode), words = get_mp_bits_words (mode);
   ADDR_T pop_sp = A68G_SP;
   MP_T *u = (MP_T *) STACK_OFFSET (-2 * size), *v = (MP_T *) STACK_OFFSET (-size);
   MP_BITS_T *row_u = stack_mp_bits (p, u, mode), *row_v = stack_mp_bits (p, v, mode);
@@ -564,7 +564,7 @@ void genie_and_mp (NODE_T * p)
 void genie_or_mp (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
-  int size = SIZE (mode), words = get_mp_bits_words (mode);
+  size_t size = SIZE (mode), words = get_mp_bits_words (mode);
   ADDR_T pop_sp = A68G_SP;
   MP_T *u = (MP_T *) STACK_OFFSET (-2 * size), *v = (MP_T *) STACK_OFFSET (-size);
   MP_BITS_T *row_u = stack_mp_bits (p, u, mode), *row_v = stack_mp_bits (p, v, mode);
@@ -581,7 +581,7 @@ void genie_or_mp (NODE_T * p)
 void genie_xor_mp (NODE_T * p)
 {
   MOID_T *mode = LHS_MODE (p);
-  int size = SIZE (mode), words = get_mp_bits_words (mode);
+  size_t size = SIZE (mode), words = get_mp_bits_words (mode);
   ADDR_T pop_sp = A68G_SP;
   MP_T *u = (MP_T *) STACK_OFFSET (-2 * size), *v = (MP_T *) STACK_OFFSET (-size);
   MP_BITS_T *row_u = stack_mp_bits (p, u, mode), *row_v = stack_mp_bits (p, v, mode);
@@ -625,7 +625,7 @@ void genie_long_mp_max_bits (NODE_T * p)
 void genie_lengthen_long_bits_to_row_bool (NODE_T * p)
 {
   MOID_T *m = MOID (SUB (p));
-  int size = SIZE (m), width = get_mp_bits_width (m), words = get_mp_bits_words (m);
+  size_t size = SIZE (m), width = get_mp_bits_width (m), words = get_mp_bits_words (m);
   ADDR_T pop_sp = A68G_SP;
 // Calculate and convert BITS value.
   MP_T *x = (MP_T *) STACK_OFFSET (-size);
