@@ -109,7 +109,7 @@ void renumber_moids (MOID_T * p, int n)
 
 MOID_T *register_extra_mode (MOID_T ** z, MOID_T * u)
 {
-  // If we already know this mode, return the existing entry; otherwise link it in.
+// If we already know this mode, return the existing entry; otherwise link it in.
   for (MOID_T *head = TOP_MOID (&A68G_JOB); head != NO_MOID; FORWARD (head)) {
     if (prove_moid_equivalence (head, u)) {
       return head;
@@ -127,9 +127,9 @@ MOID_T *add_mode (MOID_T ** z, int att, int dim, NODE_T * node, MOID_T * sub, PA
 {
   MOID_T *new_mode = new_moid ();
   if (sub == NO_MOID) {
-    ABEND (att == REF_SYMBOL, ERROR_INTERNAL_CONSISTENCY, __func__);
-    ABEND (att == FLEX_SYMBOL, ERROR_INTERNAL_CONSISTENCY, __func__);
-    ABEND (att == ROW_SYMBOL, ERROR_INTERNAL_CONSISTENCY, __func__);
+    ABEND (att == REF_SYMBOL, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
+    ABEND (att == FLEX_SYMBOL, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
+    ABEND (att == ROW_SYMBOL, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   }
   USE (new_mode) = A68G_FALSE;
   SIZE (new_mode) = 0;
@@ -518,25 +518,25 @@ void get_mode_from_denotation (NODE_T * p, int sizety)
         MOID (p) = (sizety > 0 ? M_LONG_LONG_REAL : M_REAL);
       }
     } else if (IS (p, BITS_DENOTATION)) {
-#if (A68G_LEVEL <= 2)
-      if (sizety == 0) {
-        MOID (p) = M_BITS;
-      } else if (sizety == 1) {
-        MOID (p) = M_LONG_BITS;
-      } else if (sizety == 2) {
-        MOID (p) = M_LONG_LONG_BITS;
-      } else {
-        MOID (p) = (sizety > 0 ? M_LONG_LONG_BITS : M_BITS);
-      }
-#else
-      if (sizety == 0) {
-        MOID (p) = M_BITS;
-      } else if (sizety == 1) {
-        MOID (p) = M_LONG_BITS;
-      } else {
-        MOID (p) = (sizety > 0 ? M_LONG_BITS : M_BITS);
-      }
-#endif
+      #if (A68G_LEVEL <= 2)
+        if (sizety == 0) {
+          MOID (p) = M_BITS;
+        } else if (sizety == 1) {
+          MOID (p) = M_LONG_BITS;
+        } else if (sizety == 2) {
+          MOID (p) = M_LONG_LONG_BITS;
+        } else {
+          MOID (p) = (sizety > 0 ? M_LONG_LONG_BITS : M_BITS);
+        }
+      #else
+        if (sizety == 0) {
+          MOID (p) = M_BITS;
+        } else if (sizety == 1) {
+          MOID (p) = M_LONG_BITS;
+        } else {
+          MOID (p) = (sizety > 0 ? M_LONG_BITS : M_BITS);
+        }
+      #endif
     } else if (IS (p, LONGETY) || IS (p, SHORTETY)) {
       get_mode_from_denotation (NEXT (p), count_sizety (SUB (p)));
       MOID (p) = MOID (NEXT (p));
@@ -945,7 +945,7 @@ void compute_derived_modes (MODULE_T * mod)
       nlen++;
     }
   }
-  ABEND (M_STRING != M_FLEX_ROW_CHAR, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (M_STRING != M_FLEX_ROW_CHAR, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
 // Find out what modes contain rows.
   for (z = TOP_MOID (mod); z != NO_MOID; FORWARD (z)) {
     HAS_ROWS (z) = is_mode_has_row (z);
@@ -1020,9 +1020,9 @@ void make_moid_list (MODULE_T * mod)
   for (MOID_T *z = TOP_MOID (mod); z != NO_MOID; FORWARD (z)) {
     if (IS (z, INDICANT)) {
       NODE_T *u = NODE (z);
-      ABEND (NEXT (u) == NO_NODE, ERROR_INTERNAL_CONSISTENCY, __func__);
-      ABEND (NEXT_NEXT (u) == NO_NODE, ERROR_INTERNAL_CONSISTENCY, __func__);
-      ABEND (MOID (NEXT_NEXT (u)) == NO_MOID, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (NEXT (u) == NO_NODE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
+      ABEND (NEXT_NEXT (u) == NO_NODE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
+      ABEND (MOID (NEXT_NEXT (u)) == NO_MOID, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
       EQUIVALENT (z) = MOID (NEXT_NEXT (u));
     }
   }
@@ -1048,7 +1048,7 @@ void make_moid_list (MODULE_T * mod)
     }
   }
   for (MOID_T *z = TOP_MOID (mod); z != NO_MOID; FORWARD (z)) {
-    ABEND (USE (z), ERROR_INTERNAL_CONSISTENCY, __func__);
+    ABEND (USE (z), ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   }
   if (ERROR_COUNT (mod) != 0) {
     return;
