@@ -168,7 +168,7 @@ void put_refinements (void)
   while (p != NO_NODE && !IN_PRELUDE (p)) {
     FORWARD (p);
   }
-  ABEND (p == NO_NODE, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (p == NO_NODE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   NODE_T *point = p;
 // We need to substitute until the first point.
   p = TOP_NODE (&A68G_JOB);
