@@ -90,7 +90,7 @@ void append_source_line (char *str, LINE_T ** ref_l, int *line_num, char *filena
 // Allow shell command in first line, f.i. "#!/usr/share/bin/a68g".
   if (*line_num == 1) {
     if (strlen (str) >= 2 && strncmp (str, "#!", strlen ("#!")) == 0) {
-      ABEND (strstr (str, "run-script") != NO_TEXT, ERROR_SHELL_SCRIPT, __func__);
+      ABEND (strstr (str, "run-script") != NO_TEXT, ERROR_SHELL_SCRIPT, NO_TEXT);
       (*line_num)++;
       return;
     }
@@ -583,7 +583,7 @@ BOOL_T read_script_file (void)
   BUFFER filename, linenum;
   char *buffer = (char *) get_temp_heap_space (8 + A68G_PARSER (source_file_size));
   FILE_T source = FILE_SOURCE_FD (&A68G_JOB);
-  ABEND (source == -1, ERROR_ACTION, __func__);
+  ABEND (source == -1, ERROR_ACTION, NO_TEXT);
   buffer[0] = NULL_CHAR;
   UNSIGNED_T k, n = 0;
   size_t len = 8 + A68G_PARSER (source_file_size);
@@ -614,14 +614,14 @@ BOOL_T read_script_file (void)
     }
     linenum[k] = NULL_CHAR;
     num = (int) strtol (linenum, NO_REF, 10);
-    ABEND (errno == ERANGE, ERROR_INTERNAL_CONSISTENCY, __func__);
+    ABEND (errno == ERANGE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
 // COPY original line into buffer.
     ASSERT (io_read (source, &ch, 1) == 1);
     char *line = &buffer[n];
     while (ch != NEWLINE_CHAR) {
       buffer[n++] = ch;
       ASSERT (io_read (source, &ch, 1) == 1);
-      ABEND (n >= len, ERROR_ACTION, __func__);
+      ABEND (n >= len, ERROR_ACTION, NO_TEXT);
     }
     buffer[n++] = NEWLINE_CHAR;
     buffer[n] = NULL_CHAR;
@@ -668,12 +668,12 @@ BOOL_T read_source_file (void)
   line_num = 1;
   errno = 0;
   text = (char *) get_temp_heap_space (8 + A68G_PARSER (source_file_size));
-  ABEND (errno != 0 || text == NO_TEXT, ERROR_MEMORY_FULL, __func__);
+  ABEND (errno != 0 || text == NO_TEXT, ERROR_MEMORY_FULL, NO_TEXT);
   ASSERT (lseek (f, 0, SEEK_SET) >= 0);
-  ABEND (errno != 0, ERROR_ACTION, __func__);
+  ABEND (errno != 0, ERROR_ACTION, NO_TEXT);
   errno = 0;
   bytes_read = (int) io_read (f, text, A68G_PARSER (source_file_size));
-  ABEND (errno != 0 || bytes_read != A68G_PARSER (source_file_size), ERROR_ACTION, __func__);
+  ABEND (errno != 0 || bytes_read != A68G_PARSER (source_file_size), ERROR_ACTION, NO_TEXT);
 // Little test on stropping.
   char *pr1 = "'PR'QUOTESTROPPING'PR'";
   char *pr2 = "'PRAGMAT'QUOTESTROPPING'PRAGMAT'";
@@ -735,9 +735,9 @@ BOOL_T read_source_file (void)
 char next_char (LINE_T ** ref_l, char **ref_s, BOOL_T allow_typo)
 {
   char ch;
-#if defined (NO_TYPO)
-  allow_typo = A68G_FALSE;
-#endif
+  #if defined (NO_TYPO)
+    allow_typo = A68G_FALSE;
+  #endif
   LOW_STACK_ALERT (NO_NODE);
 // Source empty?.
   if (*ref_l == NO_LINE) {
@@ -1588,7 +1588,7 @@ BOOL_T lexical_analyser (void)
       return A68G_FALSE;
     }
   } else {
-    A68G_PARSER (max_scan_buf_length) += KILOBYTE;       // for the environ, more than enough
+    A68G_PARSER (max_scan_buf_length) += A68G_KILO;       // for the environ, more than enough
     A68G_PARSER (scan_buf) = (char *) get_temp_heap_space (A68G_PARSER (max_scan_buf_length));
 // Errors in file?.
     if (!read_source_file ()) {
