@@ -480,7 +480,7 @@ void test_firmly_related_ops_local (NODE_T * p, TAG_T * s)
       if (t != NO_TAG) {
         if (TAG_TABLE (t) == A68G_STANDENV) {
           diagnostic (A68G_ERROR, p, ERROR_OPERATOR_RELATED, MOID (s), NSYMBOL (NODE (s)), MOID (t), NSYMBOL (NODE (t)));
-          ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+          ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
         } else {
           diagnostic (A68G_ERROR, p, ERROR_OPERATOR_RELATED, MOID (s), NSYMBOL (NODE (s)), MOID (t), NSYMBOL (NODE (t)));
         }
@@ -599,7 +599,7 @@ TAG_T *add_tag (TABLE_T * s, int a, NODE_T * n, MOID_T * m, int p)
         break;
       }
     default: {
-        ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+        ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
       }
     }
     return z;
@@ -636,7 +636,7 @@ TAG_T *find_tag_global (TABLE_T * table, int a, char *name)
         break;
       }
     default: {
-        ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+        ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
         break;
       }
     }
@@ -689,7 +689,7 @@ TAG_T *find_tag_local (TABLE_T * table, int a, const char *name)
     } else if (a == LABEL) {
       s = LABELS (table);
     } else {
-      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     }
     for (; s != NO_TAG; FORWARD (s)) {
       if (NSYMBOL (NODE (s)) == name) {
