@@ -65,9 +65,9 @@ void top_down_diagnose (NODE_T * start, NODE_T * p, int clause, int expected)
 {
   NODE_T *issue = (p != NO_NODE ? p : start);
   if (expected != 0) {
-    diagnostic (A68_SYNTAX_ERROR, issue, ERROR_EXPECTED_NEAR, expected, clause, NSYMBOL (start), LINE (INFO (start)));
+    diagnostic (A68G_SYNTAX_ERROR, issue, ERROR_EXPECTED_NEAR, expected, clause, NSYMBOL (start), LINE (INFO (start)));
   } else {
-    diagnostic (A68_SYNTAX_ERROR, issue, ERROR_UNBALANCED_KEYWORD, clause, NSYMBOL (start), LINE (INFO (start)));
+    diagnostic (A68G_SYNTAX_ERROR, issue, ERROR_UNBALANCED_KEYWORD, clause, NSYMBOL (start), LINE (INFO (start)));
   }
 }
 
@@ -76,8 +76,8 @@ void top_down_diagnose (NODE_T * start, NODE_T * p, int clause, int expected)
 void tokens_exhausted (const NODE_T * p, NODE_T * q)
 {
   if (p == NO_NODE) {
-    diagnostic (A68_SYNTAX_ERROR, q, ERROR_KEYWORD);
-    longjmp (A68_PARSER (top_down_crash_exit), 1);
+    diagnostic (A68G_SYNTAX_ERROR, q, ERROR_KEYWORD);
+    longjmp (A68G_PARSER (top_down_crash_exit), 1);
   }
 }
 
@@ -177,7 +177,7 @@ NODE_T *top_down_loop (NODE_T * p)
       ATTRIBUTE (q) = DEFINING_IDENTIFIER;
     } else {
       top_down_diagnose (start, q, LOOP_CLAUSE, IDENTIFIER);
-      longjmp (A68_PARSER (top_down_crash_exit), 1);
+      longjmp (A68G_PARSER (top_down_crash_exit), 1);
     }
     tokens_exhausted (FORWARD (q), start);
     if (is_one_of (q, FROM_SYMBOL, BY_SYMBOL, TO_SYMBOL, DOWNTO_SYMBOL, WHILE_SYMBOL, STOP)) {
@@ -186,7 +186,7 @@ NODE_T *top_down_loop (NODE_T * p)
       ATTRIBUTE (q) = ALT_DO_SYMBOL;
     } else {
       top_down_diagnose (start, q, LOOP_CLAUSE, STOP);
-      longjmp (A68_PARSER (top_down_crash_exit), 1);
+      longjmp (A68G_PARSER (top_down_crash_exit), 1);
     }
   }
   if (IS (q, FROM_SYMBOL)) {
@@ -199,7 +199,7 @@ NODE_T *top_down_loop (NODE_T * p)
       ATTRIBUTE (q) = ALT_DO_SYMBOL;
     } else {
       top_down_diagnose (start, q, LOOP_CLAUSE, STOP);
-      longjmp (A68_PARSER (top_down_crash_exit), 1);
+      longjmp (A68G_PARSER (top_down_crash_exit), 1);
     }
     make_sub (start, PREVIOUS (q), FROM_SYMBOL);
   }
@@ -213,7 +213,7 @@ NODE_T *top_down_loop (NODE_T * p)
       ATTRIBUTE (q) = ALT_DO_SYMBOL;
     } else {
       top_down_diagnose (start, q, LOOP_CLAUSE, STOP);
-      longjmp (A68_PARSER (top_down_crash_exit), 1);
+      longjmp (A68G_PARSER (top_down_crash_exit), 1);
     }
     make_sub (start, PREVIOUS (q), BY_SYMBOL);
   }
@@ -227,7 +227,7 @@ NODE_T *top_down_loop (NODE_T * p)
       ATTRIBUTE (q) = ALT_DO_SYMBOL;
     } else {
       top_down_diagnose (start, q, LOOP_CLAUSE, STOP);
-      longjmp (A68_PARSER (top_down_crash_exit), 1);
+      longjmp (A68G_PARSER (top_down_crash_exit), 1);
     }
     make_sub (start, PREVIOUS (q), TO_SYMBOL);
   }
@@ -239,7 +239,7 @@ NODE_T *top_down_loop (NODE_T * p)
       ATTRIBUTE (q) = ALT_DO_SYMBOL;
     } else {
       top_down_diagnose (start, q, LOOP_CLAUSE, DO_SYMBOL);
-      longjmp (A68_PARSER (top_down_crash_exit), 1);
+      longjmp (A68G_PARSER (top_down_crash_exit), 1);
     }
     make_sub (start, PREVIOUS (q), WHILE_SYMBOL);
   }
@@ -250,7 +250,7 @@ NODE_T *top_down_loop (NODE_T * p)
     tokens_exhausted (q, start);
     if (!IS (q, OD_SYMBOL)) {
       top_down_diagnose (start, q, LOOP_CLAUSE, OD_SYMBOL);
-      longjmp (A68_PARSER (top_down_crash_exit), 1);
+      longjmp (A68G_PARSER (top_down_crash_exit), 1);
     }
     make_sub (start, q, k);
   }
@@ -310,13 +310,13 @@ void top_down_untils (NODE_T * p)
 
 NODE_T *top_down_series (NODE_T * p)
 {
-  BOOL_T siga = A68_TRUE;
+  BOOL_T siga = A68G_TRUE;
   while (siga) {
-    siga = A68_FALSE;
+    siga = A68G_FALSE;
     p = top_down_skip_unit (p);
     if (p != NO_NODE) {
       if (is_one_of (p, SEMI_SYMBOL, EXIT_SYMBOL, COMMA_SYMBOL, STOP)) {
-        siga = A68_TRUE;
+        siga = A68G_TRUE;
         FORWARD (p);
       }
     }
@@ -331,7 +331,7 @@ NODE_T *top_down_begin (NODE_T * begin_p)
   NODE_T *end_p = top_down_series (NEXT (begin_p));
   if (end_p == NO_NODE || !IS (end_p, END_SYMBOL)) {
     top_down_diagnose (begin_p, end_p, ENCLOSED_CLAUSE, END_SYMBOL);
-    longjmp (A68_PARSER (top_down_crash_exit), 1);
+    longjmp (A68G_PARSER (top_down_crash_exit), 1);
     return NO_NODE;
   } else {
     make_sub (begin_p, end_p, BEGIN_SYMBOL);
@@ -345,8 +345,8 @@ NODE_T *top_down_code (NODE_T * code_p)
 {
   NODE_T *edoc_p = top_down_series (NEXT (code_p));
   if (edoc_p == NO_NODE || !IS (edoc_p, EDOC_SYMBOL)) {
-    diagnostic (A68_SYNTAX_ERROR, code_p, ERROR_KEYWORD);
-    longjmp (A68_PARSER (top_down_crash_exit), 1);
+    diagnostic (A68G_SYNTAX_ERROR, code_p, ERROR_KEYWORD);
+    longjmp (A68G_PARSER (top_down_crash_exit), 1);
     return NO_NODE;
   } else {
     make_sub (code_p, edoc_p, CODE_SYMBOL);
@@ -365,7 +365,7 @@ NODE_T *top_down_open (NODE_T * open_p)
   }
   if (then_bar_p == NO_NODE || !IS (then_bar_p, THEN_BAR_SYMBOL)) {
     top_down_diagnose (open_p, then_bar_p, ENCLOSED_CLAUSE, STOP);
-    longjmp (A68_PARSER (top_down_crash_exit), 1);
+    longjmp (A68G_PARSER (top_down_crash_exit), 1);
   }
   make_sub (open_p, PREVIOUS (then_bar_p), OPEN_SYMBOL);
   elif_bar_p = top_down_series (NEXT (then_bar_p));
@@ -378,7 +378,7 @@ NODE_T *top_down_open (NODE_T * open_p)
     NODE_T *close_p = top_down_series (NEXT (elif_bar_p));
     if (close_p == NO_NODE || !IS (close_p, CLOSE_SYMBOL)) {
       top_down_diagnose (open_p, elif_bar_p, ENCLOSED_CLAUSE, CLOSE_SYMBOL);
-      longjmp (A68_PARSER (top_down_crash_exit), 1);
+      longjmp (A68G_PARSER (top_down_crash_exit), 1);
     }
     make_sub (then_bar_p, PREVIOUS (elif_bar_p), THEN_BAR_SYMBOL);
     make_sub (elif_bar_p, PREVIOUS (close_p), THEN_BAR_SYMBOL);
@@ -392,7 +392,7 @@ NODE_T *top_down_open (NODE_T * open_p)
     return close_p;
   } else {
     top_down_diagnose (open_p, elif_bar_p, ENCLOSED_CLAUSE, CLOSE_SYMBOL);
-    longjmp (A68_PARSER (top_down_crash_exit), 1);
+    longjmp (A68G_PARSER (top_down_crash_exit), 1);
     return NO_NODE;
   }
 }
@@ -407,7 +407,7 @@ NODE_T *top_down_sub (NODE_T * sub_p)
     return NEXT (sub_p);
   } else {
     top_down_diagnose (sub_p, bus_p, 0, BUS_SYMBOL);
-    longjmp (A68_PARSER (top_down_crash_exit), 1);
+    longjmp (A68G_PARSER (top_down_crash_exit), 1);
     return NO_NODE;
   }
 }
@@ -422,7 +422,7 @@ NODE_T *top_down_acco (NODE_T * acco_p)
     return NEXT (acco_p);
   } else {
     top_down_diagnose (acco_p, occa_p, ENCLOSED_CLAUSE, OCCA_SYMBOL);
-    longjmp (A68_PARSER (top_down_crash_exit), 1);
+    longjmp (A68G_PARSER (top_down_crash_exit), 1);
     return NO_NODE;
   }
 }
@@ -434,7 +434,7 @@ NODE_T *top_down_if (NODE_T * if_p)
   NODE_T *then_p = top_down_series (NEXT (if_p)), *elif_p;
   if (then_p == NO_NODE || !IS (then_p, THEN_SYMBOL)) {
     top_down_diagnose (if_p, then_p, CONDITIONAL_CLAUSE, THEN_SYMBOL);
-    longjmp (A68_PARSER (top_down_crash_exit), 1);
+    longjmp (A68G_PARSER (top_down_crash_exit), 1);
   }
   make_sub (if_p, PREVIOUS (then_p), IF_SYMBOL);
   elif_p = top_down_series (NEXT (then_p));
@@ -447,7 +447,7 @@ NODE_T *top_down_if (NODE_T * if_p)
     NODE_T *fi_p = top_down_series (NEXT (elif_p));
     if (fi_p == NO_NODE || !IS (fi_p, FI_SYMBOL)) {
       top_down_diagnose (if_p, fi_p, CONDITIONAL_CLAUSE, FI_SYMBOL);
-      longjmp (A68_PARSER (top_down_crash_exit), 1);
+      longjmp (A68G_PARSER (top_down_crash_exit), 1);
     } else {
       make_sub (then_p, PREVIOUS (elif_p), THEN_SYMBOL);
       make_sub (elif_p, PREVIOUS (fi_p), ELSE_SYMBOL);
@@ -462,7 +462,7 @@ NODE_T *top_down_if (NODE_T * if_p)
     return fi_p;
   } else {
     top_down_diagnose (if_p, elif_p, CONDITIONAL_CLAUSE, FI_SYMBOL);
-    longjmp (A68_PARSER (top_down_crash_exit), 1);
+    longjmp (A68G_PARSER (top_down_crash_exit), 1);
     return NO_NODE;
   }
 }
@@ -474,7 +474,7 @@ NODE_T *top_down_case (NODE_T * case_p)
   NODE_T *in_p = top_down_series (NEXT (case_p)), *ouse_p;
   if (in_p == NO_NODE || !IS (in_p, IN_SYMBOL)) {
     top_down_diagnose (case_p, in_p, ENCLOSED_CLAUSE, IN_SYMBOL);
-    longjmp (A68_PARSER (top_down_crash_exit), 1);
+    longjmp (A68G_PARSER (top_down_crash_exit), 1);
   }
   make_sub (case_p, PREVIOUS (in_p), CASE_SYMBOL);
   ouse_p = top_down_series (NEXT (in_p));
@@ -487,7 +487,7 @@ NODE_T *top_down_case (NODE_T * case_p)
     NODE_T *esac_p = top_down_series (NEXT (ouse_p));
     if (esac_p == NO_NODE || !IS (esac_p, ESAC_SYMBOL)) {
       top_down_diagnose (case_p, esac_p, ENCLOSED_CLAUSE, ESAC_SYMBOL);
-      longjmp (A68_PARSER (top_down_crash_exit), 1);
+      longjmp (A68G_PARSER (top_down_crash_exit), 1);
     } else {
       make_sub (in_p, PREVIOUS (ouse_p), IN_SYMBOL);
       make_sub (ouse_p, PREVIOUS (esac_p), OUT_SYMBOL);
@@ -502,7 +502,7 @@ NODE_T *top_down_case (NODE_T * case_p)
     return esac_p;
   } else {
     top_down_diagnose (case_p, ouse_p, ENCLOSED_CLAUSE, ESAC_SYMBOL);
-    longjmp (A68_PARSER (top_down_crash_exit), 1);
+    longjmp (A68G_PARSER (top_down_crash_exit), 1);
     return NO_NODE;
   }
 }
@@ -545,7 +545,7 @@ NODE_T *top_down_format_open (NODE_T * open_p)
     return NEXT (open_p);
   } else {
     top_down_diagnose (open_p, close_p, 0, FORMAT_CLOSE_SYMBOL);
-    longjmp (A68_PARSER (top_down_crash_exit), 1);
+    longjmp (A68G_PARSER (top_down_crash_exit), 1);
     return NO_NODE;
   }
 }
@@ -587,7 +587,7 @@ void top_down_formats (NODE_T * p)
       }
       if (f == NO_NODE) {
         top_down_diagnose (p, f, FORMAT_TEXT, FORMAT_DELIMITER_SYMBOL);
-        longjmp (A68_PARSER (top_down_crash_exit), 1);
+        longjmp (A68G_PARSER (top_down_crash_exit), 1);
       } else {
         make_sub (q, f, FORMAT_DELIMITER_SYMBOL);
       }
@@ -600,7 +600,7 @@ void top_down_formats (NODE_T * p)
 void top_down_parser (NODE_T * p)
 {
   if (p != NO_NODE) {
-    if (!setjmp (A68_PARSER (top_down_crash_exit))) {
+    if (!setjmp (A68G_PARSER (top_down_crash_exit))) {
       (void) top_down_series (p);
       top_down_loops (p);
       top_down_untils (p);
