@@ -130,7 +130,7 @@ void init_before_tokeniser (void)
   set_up_tables ();
 // Various initialisations.
   ERROR_COUNT (&A68G_JOB) = WARNING_COUNT (&A68G_JOB) = 0;
-  ABEND (errno != 0, ERROR_MEMORY_FULL, __func__);
+  ABEND (errno != 0, ERROR_MEMORY_FULL, NO_TEXT);
   errno = 0;
 }
 
@@ -996,7 +996,7 @@ BOOL_T is_one_of (NODE_T * p, ...)
 void make_sub (NODE_T * p, NODE_T * q, int t)
 {
   NODE_T *z = new_node ();
-  ABEND (p == NO_NODE || q == NO_NODE, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (p == NO_NODE || q == NO_NODE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   *z = *p;
   if (GINFO (p) != NO_GINFO) {
     GINFO (z) = new_genie_info ();
