@@ -59,7 +59,7 @@ char *inline_mode (MOID_T * m)
 
 //! @brief Compile inline arguments.
 
-void inline_arguments (NODE_T * p, FILE_T out, int phase, int *size)
+void inline_arguments (NODE_T * p, FILE_T out, int phase, size_t *size)
 {
   if (p == NO_NODE) {
     return;
@@ -182,7 +182,7 @@ void inline_widening (NODE_T * p, FILE_T out, int phase)
 void inline_dereference_identifier (NODE_T * p, FILE_T out, int phase)
 {
   NODE_T *q = stems_from (SUB (p), IDENTIFIER);
-  ABEND (q == NO_NODE, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (q == NO_NODE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   if (phase == L_DECLARE) {
     if (signed_in (BOOK_DEREF, L_DECLARE, NSYMBOL (q)) != NO_BOOK) {
       return;
@@ -364,7 +364,7 @@ void inline_dereference_slice (NODE_T * p, FILE_T out, int phase)
       if (IS (row_mode, REF_SYMBOL) && IS (SUB (row_mode), ROW_SYMBOL)) {
         indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "GET_DESCRIPTOR (%s, %s, DEREF (A68G_ROW, %s));\n", arr, tup, idf));
       } else {
-        ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+        ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
       }
       sign_in (BOOK_DECL, L_EXECUTE, NSYMBOL (p), (void *) indx, NUMBER (prim));
     } else if (same_tree (indx, (NODE_T *) (INFO (entry))) == A68G_FALSE) {
@@ -397,7 +397,7 @@ void inline_dereference_slice (NODE_T * p, FILE_T out, int phase)
     } else if (basic_mode (mode)) {
       undent (out, drf);
     } else {
-      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     }
   }
 }
@@ -447,7 +447,7 @@ void inline_slice_ref_to_ref (NODE_T * p, FILE_T out, int phase)
       if (IS (row_mode, REF_SYMBOL) && IS (SUB (row_mode), ROW_SYMBOL)) {
         indentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "GET_DESCRIPTOR (%s, %s, DEREF (A68G_ROW, %s));\n", arr, tup, idf));
       } else {
-        ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+        ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
       }
       sign_in (BOOK_DECL, L_EXECUTE, NSYMBOL (p), (void *) indx, NUMBER (prim));
     } else if (same_tree (indx, (NODE_T *) (INFO (entry))) == A68G_FALSE) {
@@ -550,7 +550,7 @@ void inline_slice (NODE_T * p, FILE_T out, int phase)
     } else if (basic_mode (mode)) {
       undentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "%s", drf));
     } else {
-      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     }
   }
 }
@@ -807,13 +807,13 @@ void inline_conditional (NODE_T * p, FILE_T out, int phase)
   if (IS (p, IF_PART) || IS (p, OPEN_PART)) {
     if_part = p;
   } else {
-    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   }
   FORWARD (p);
   if (IS (p, THEN_PART) || IS (p, CHOICE)) {
     then_part = p;
   } else {
-    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   }
   FORWARD (p);
   if (IS (p, ELSE_PART) || IS (p, CHOICE)) {
@@ -902,7 +902,7 @@ void inline_dereference_selection (NODE_T * p, FILE_T out, int phase)
     } else if (basic_mode (SUB_MOID (p))) {
       undent (out, sel);
     } else {
-      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     }
   }
 }
@@ -954,7 +954,7 @@ void inline_selection (NODE_T * p, FILE_T out, int phase)
     if (primitive_mode (MOID (p))) {
       undentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "_VALUE_ (%s)", sel));
     } else {
-      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     }
   }
 }
@@ -1006,7 +1006,7 @@ void inline_selection_ref_to_ref (NODE_T * p, FILE_T out, int phase)
     if (primitive_mode (SUB_MOID (p))) {
       undentf (out, a68g_bufprt (A68G (edit_line), SNPRINTF_SIZE, "(&%s)", sel));
     } else {
-      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     }
   }
 }
@@ -1144,7 +1144,7 @@ void inline_unit (NODE_T * p, FILE_T out, int phase)
     } else if (IS (mode, REF_SYMBOL) && IS (row_mode, REF_SYMBOL) && SUB (mode) == SUB_SUB (row_mode)) {
       inline_slice_ref_to_ref (p, out, phase);
     } else {
-      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     }
   } else if (IS (p, DEREFERENCING) && stems_from (SUB (p), SLICE) != NO_NODE) {
     inline_dereference_slice (SUB (p), out, phase);
@@ -1159,7 +1159,7 @@ void inline_unit (NODE_T * p, FILE_T out, int phase)
     } else if (IS (struct_mode, STRUCT_SYMBOL) && primitive_mode (mode)) {
       inline_selection (p, out, phase);
     } else {
-      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     }
   } else if (IS (p, DENOTATION)) {
     inline_denotation (p, out, phase);
