@@ -66,7 +66,7 @@ void init_curses (void)
 
 int rgetchar (void)
 {
-#if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+#if defined (BUILD_WINDOWS)
   if (kbhit ()) {
     return getch ();
   } else {
@@ -75,15 +75,16 @@ int rgetchar (void)
 #else
   struct timeval tv;
   TV_SEC (&tv) = 0;
-  TV_USEC (&tv) = 100;
+  TV_USEC (&tv) = 1000;
   fd_set fd;
   FD_ZERO (&fd);
   FD_SET (0, &fd);
-  if (select (1, &fd, NULL, NULL, &tv)) {
-// FD_ISSET(0, &fd) will be true.  
-    return getch ();
-  } else {
+  int rc = select (1, &fd, NULL, NULL, &tv);
+  if (rc == -1 || rc == 0) {
     return NULL_CHAR;
+  } else {
+    // FD_ISSET(0, &fd) will be true.  
+    return getch ();
   }
 #endif
 }
