@@ -228,7 +228,7 @@ NODE_T *scan_format_pattern (NODE_T * p, A68G_REF ref_file)
           } else if (WRITE_MOOD (file)) {
             write_insertion (picture, ref_file, INSERTION_NORMAL);
           } else {
-            ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+            ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
           }
           COUNT (collitem) = 0; // This insertion is now done
         } else if (IS (picture, REPLICATOR) || IS (picture, COLLECTION)) {
@@ -337,8 +337,8 @@ void write_insertion (NODE_T * p, A68G_REF ref_file, MOOD_T mood)
       if (mood & INSERTION_NORMAL) {
         add_string_transput_buffer (p, FORMATTED_BUFFER, NSYMBOL (p));
       } else if (mood & INSERTION_BLANK) {
-        int k = (int) strlen (NSYMBOL (p));
-        for (int j = 1; j <= k; j++) {
+        size_t k = strlen (NSYMBOL (p));
+        for (size_t j = 1; j <= k; j++) {
           plusab_transput_buffer (p, FORMATTED_BUFFER, BLANK_CHAR);
         }
       }
@@ -459,7 +459,7 @@ void write_number_generic (NODE_T * p, MOID_T * mode, BYTE_T * item, int mod)
   POP_REF (p, &row);
   A68G_ARRAY *arr; A68G_TUPLE *tup;
   GET_DESCRIPTOR (arr, tup, &row);
-  int size = ROW_SIZE (tup);
+  size_t size = ROW_SIZE (tup);
   if (size > 0) {
     BYTE_T *base_address = DEREF (BYTE_T, &ARRAY (arr));
     for (int i = LWB (tup); i <= UPB (tup); i++) {
@@ -630,10 +630,10 @@ void write_c_pattern (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_REF ref_fil
         after = A68G_LONG_LONG_REAL_WIDTH - 1;
       }
       scan_c_pattern (SUB (p), &right_align, &sign, &digits, &after, &letter);
-      if (digits == 0 && after > 0) {
-        width = after + 2;
+      if (digits == 0) {
+        width = 0;
       } else if (digits > 0) {
-        width = digits;
+        width = digits + after + 2;
       }
       unite_to_number (p, mode, item);
       PUSH_VALUE (p, (sign ? width : -width), A68G_INT);
@@ -659,11 +659,11 @@ void write_c_pattern (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_REF ref_fil
       if (mode == M_BITS) {
         width = (int) ceil ((REAL_T) A68G_BITS_WIDTH / (REAL_T) nibble);
       } else if (mode == M_LONG_BITS || mode == M_LONG_LONG_BITS) {
-#if (A68G_LEVEL <= 2)
-        width = (int) ceil ((REAL_T) get_mp_bits_width (mode) / (REAL_T) nibble);
-#else
-        width = (int) ceil ((REAL_T) A68G_LONG_BITS_WIDTH / (REAL_T) nibble);
-#endif
+        #if (A68G_LEVEL <= 2)
+          width = (int) ceil ((REAL_T) get_mp_bits_width (mode) / (REAL_T) nibble);
+        #else
+          width = (int) ceil ((REAL_T) A68G_LONG_BITS_WIDTH / (REAL_T) nibble);
+        #endif
       }
     }
     if (mode == M_BITS) {
@@ -675,39 +675,39 @@ void write_c_pattern (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_REF ref_fil
       }
       str = get_transput_buffer (EDIT_BUFFER);
     } else if (mode == M_LONG_BITS) {
-#if (A68G_LEVEL >= 3)
-      A68G_LONG_BITS *z = (A68G_LONG_BITS *) item;
-      reset_transput_buffer (EDIT_BUFFER);
-      if (!convert_radix_double (p, VALUE (z), radix, width)) {
-        errno = EDOM;
-        value_error (p, mode, ref_file);
-      }
-      str = get_transput_buffer (EDIT_BUFFER);
-#else
-      int digits = DIGITS (mode);
-      MP_T *u = (MP_T *) item;
-      MP_T *v = nil_mp (p, digits);
-      MP_T *w = nil_mp (p, digits);
-      reset_transput_buffer (EDIT_BUFFER);
-      if (!convert_radix_mp (p, u, radix, width, mode, v, w)) {
-        errno = EDOM;
-        value_error (p, mode, ref_file);
-      }
-      str = get_transput_buffer (EDIT_BUFFER);
-#endif
+      #if (A68G_LEVEL >= 3)
+        A68G_LONG_BITS *z = (A68G_LONG_BITS *) item;
+        reset_transput_buffer (EDIT_BUFFER);
+        if (!convert_radix_double (p, VALUE (z), radix, width)) {
+          errno = EDOM;
+          value_error (p, mode, ref_file);
+        }
+        str = get_transput_buffer (EDIT_BUFFER);
+      #else
+        int digits = DIGITS (mode);
+        MP_T *u = (MP_T *) item;
+        MP_T *v = nil_mp (p, digits);
+        MP_T *w = nil_mp (p, digits);
+        reset_transput_buffer (EDIT_BUFFER);
+        if (!convert_radix_mp (p, u, radix, width, mode, v, w)) {
+          errno = EDOM;
+          value_error (p, mode, ref_file);
+        }
+        str = get_transput_buffer (EDIT_BUFFER);
+      #endif
     } else if (mode == M_LONG_LONG_BITS) {
-#if (A68G_LEVEL <= 2)
-      int digits = DIGITS (mode);
-      MP_T *u = (MP_T *) item;
-      MP_T *v = nil_mp (p, digits);
-      MP_T *w = nil_mp (p, digits);
-      reset_transput_buffer (EDIT_BUFFER);
-      if (!convert_radix_mp (p, u, radix, width, mode, v, w)) {
-        errno = EDOM;
-        value_error (p, mode, ref_file);
-      }
-      str = get_transput_buffer (EDIT_BUFFER);
-#endif
+      #if (A68G_LEVEL <= 2)
+        int digits = DIGITS (mode);
+        MP_T *u = (MP_T *) item;
+        MP_T *v = nil_mp (p, digits);
+        MP_T *w = nil_mp (p, digits);
+        reset_transput_buffer (EDIT_BUFFER);
+        if (!convert_radix_mp (p, u, radix, width, mode, v, w)) {
+          errno = EDOM;
+          value_error (p, mode, ref_file);
+        }
+        str = get_transput_buffer (EDIT_BUFFER);
+      #endif
     }
   }
 // Did the conversion succeed?.
@@ -728,7 +728,7 @@ void write_c_pattern (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_REF ref_fil
         while (str[0] == BLANK_CHAR) {
           str++;
         }
-        int blanks = width - (int) strlen (str);
+        int blanks = width - strlen (str);
         if (blanks >= 0) {
           add_string_transput_buffer (p, FORMATTED_BUFFER, str);
           while (blanks--) {
@@ -742,7 +742,7 @@ void write_c_pattern (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_REF ref_fil
         while (str[0] == BLANK_CHAR) {
           str++;
         }
-        int blanks = width - (int) strlen (str);
+        int blanks = width - strlen (str);
         if (blanks >= 0) {
           while (blanks--) {
             plusab_transput_buffer (p, FORMATTED_BUFFER, BLANK_CHAR);
@@ -857,7 +857,7 @@ void read_c_pattern (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_REF ref_file
         A68G_FILE *file = FILE_DEREF (&ref_file);
         int ch;
         ASSERT (a68g_bufprt (str, (size_t) TRANSPUT_BUFFER_SIZE, "%dr", radix) >= 0);
-        set_transput_buffer_index (INPUT_BUFFER, (int) strlen (str));
+        set_transput_buffer_index (INPUT_BUFFER, strlen (str));
         ch = char_scanner (file);
         while (ch != EOF_CHAR && (IS_SPACE (ch) || IS_NL_FF (ch))) {
           if (IS_NL_FF (ch)) {
@@ -873,7 +873,7 @@ void read_c_pattern (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_REF ref_file
         unchar_scanner (p, file, (char) ch);
       } else {
         ASSERT (a68g_bufprt (str, (size_t) TRANSPUT_BUFFER_SIZE, "%dr", radix) >= 0);
-        set_transput_buffer_index (INPUT_BUFFER, (int) strlen (str));
+        set_transput_buffer_index (INPUT_BUFFER, strlen (str));
         scan_n_chars (p, width, mode, ref_file);
       }
       genie_string_to_value (p, mode, item, ref_file);
@@ -1078,28 +1078,23 @@ void write_integral_pattern (NODE_T * p, MOID_T * mode, MOID_T * root, BYTE_T *
     count_zd_frames (p, &width);
 // Make string.
     reset_transput_buffer (EDIT_BUFFER);
+    int digits = DIGITS (M_LONG_LONG_INT);
+    MP_T *z = nil_mp (p, digits);
     if (mode == M_INT) {
-      A68G_INT *z = (A68G_INT *) item;
-      sign = SIGN (VALUE (z));
-      str = sub_whole (p, ABS (VALUE (z)), width);
+      int_to_mp (p, z, VALUE ((A68G_INT *) item), digits);
     } else if (mode == M_LONG_INT) {
-#if (A68G_LEVEL >= 3)
-      A68G_LONG_INT *z = (A68G_LONG_INT *) item;
-      DOUBLE_NUM_T w = VALUE (z);
-      sign = sign_double_int (w);
-      str = long_sub_whole_double (p, abs_double_int (w), width);
-#else
-      MP_T *z = (MP_T *) item;
-      sign = MP_SIGN (z);
-      MP_DIGIT (z, 1) = ABS (MP_DIGIT (z, 1));
-      str = long_sub_whole (p, z, DIGITS (mode), width);
-#endif
+      #if (A68G_LEVEL >= 3)
+        DOUBLE_NUM_T w = VALUE ((A68G_LONG_INT *) item);
+        double_int_to_mp (p, z, w, digits);
+      #else
+        (void) lengthen_mp (p, z, digits, (MP_T *) item, DIGITS (M_LONG_INT));
+      #endif
     } else if (mode == M_LONG_LONG_INT) {
-      MP_T *z = (MP_T *) item;
-      sign = MP_SIGN (z);
-      MP_DIGIT (z, 1) = ABS (MP_DIGIT (z, 1));
-      str = long_sub_whole (p, z, DIGITS (mode), width);
+      (void) move_mp (z, (MP_T *) item, digits);
     }
+    sign = MP_SIGN (z);
+    MP_DIGIT (z, 1) = ABS (MP_DIGIT (z, 1));
+    str = sub_whole_mp (p, z, digits, width);
 // Edit string and output.
     if (strchr (str, ERROR_CHAR) != NO_TEXT) {
       value_error (p, root, ref_file);
@@ -1109,7 +1104,7 @@ void write_integral_pattern (NODE_T * p, MOID_T * mode, MOID_T * root, BYTE_T *
     } else if (sign < 0) {
       value_sign_error (p, root, ref_file);
     }
-    put_zeroes_to_integral (p, width - (int) strlen (str));
+    put_zeroes_to_integral (p, width - strlen (str));
     add_string_transput_buffer (p, EDIT_BUFFER, str);
     str = get_transput_buffer (EDIT_BUFFER);
     mood = (MOOD_T) (DIGIT_BLANK | INSERTION_NORMAL);
@@ -1182,75 +1177,50 @@ void write_real_pattern (NODE_T * p, MOID_T * mode, MOID_T * root, BYTE_T * item
     } else {
       mant_length = 1 + stag_digits + frac_digits;
     }
-    if (mode == M_REAL || mode == M_INT) {
-      REAL_T x;
-      if (mode == M_REAL) {
-        x = VALUE ((A68G_REAL *) item);
-      } else {
-        x = (REAL_T) VALUE ((A68G_INT *) item);
-      }
+//
+    ADDR_T pop_sp2 = A68G_SP;
+    int digits = DIGITS (M_LONG_LONG_REAL);
+    MP_T *z = nil_mp (p, digits);
+    if (mode == M_INT) {
+      INT_T x = VALUE ((A68G_INT *) item);
+      (void) int_to_mp (p, z, x, digits);
+    } else if (mode == M_REAL) {
+      REAL_T x = VALUE ((A68G_REAL *) item);
       CHECK_REAL (p, x);
-      exp_value = 0;
-      sign = SIGN (x);
-      if (sign_mould != NO_NODE) {
-        put_sign_to_integral (sign_mould, sign);
-      }
-      x = ABS (x);
-      if (expo_mould != NO_NODE) {
-        standardise (&x, stag_digits, frac_digits, &exp_value);
-      }
-      str = sub_fixed (p, x, mant_length, frac_digits);
-    } else if (mode == M_LONG_REAL || mode == M_LONG_INT) {
-#if (A68G_LEVEL >= 3)
-      DOUBLE_NUM_T x = VALUE ((A68G_DOUBLE *) item);
-      if (mode == M_LONG_INT) {
-        x = double_int_to_double (p, x);
-      }
-      CHECK_DOUBLE_REAL (p, x.f);
-      exp_value = 0;
-      sign = sign_double (x);
-      if (sign_mould != NO_NODE) {
-        put_sign_to_integral (sign_mould, sign);
-      }
-      x.f = fabs_double (x.f);
-      if (expo_mould != NO_NODE) {
-        standardise_double (&(x.f), stag_digits, frac_digits, &exp_value);
-      }
-      str = sub_fixed_double (p, x.f, mant_length, frac_digits, A68G_LONG_REAL_WIDTH);
-#else
-      ADDR_T pop_sp2 = A68G_SP;
-      int digits = DIGITS (mode);
-      MP_T *x = nil_mp (p, digits);
-      (void) move_mp (x, (MP_T *) item, digits);
-      exp_value = 0;
-      sign = SIGN (x[2]);
-      if (sign_mould != NO_NODE) {
-        put_sign_to_integral (sign_mould, sign);
-      }
-      x[2] = ABS (x[2]);
-      if (expo_mould != NO_NODE) {
-        long_standardise (p, x, DIGITS (mode), stag_digits, frac_digits, &exp_value);
-      }
-      str = long_sub_fixed (p, x, DIGITS (mode), mant_length, frac_digits);
-      A68G_SP = pop_sp2;
-#endif
+      #if (A68G_LEVEL >= 3)
+        (void) double_to_mp (p, z, (DOUBLE_T) x, A68G_REAL_DIG, A68G_TRUE, digits);
+      #else
+        (void) real_to_mp (p, z, x, digits);
+      #endif
+    } else if (mode == M_LONG_INT) {
+      #if (A68G_LEVEL >= 3)
+        DOUBLE_NUM_T x = VALUE ((A68G_DOUBLE *) item);
+        (void) double_int_to_mp (p, z, x, digits);
+      #else
+        (void) lengthen_mp (p, z, digits, (MP_T *) item, DIGITS (M_LONG_INT));
+      #endif
+    } else if (mode == M_LONG_REAL) {
+      #if (A68G_LEVEL >= 3)
+        DOUBLE_T x = VALUE ((A68G_DOUBLE *) item).f;
+        CHECK_DOUBLE_REAL (p, x);
+        (void) double_to_mp (p, z, x, A68G_REAL_DIG, A68G_TRUE, digits);
+      #else
+        (void) lengthen_mp (p, z, digits, (MP_T *) item, DIGITS (M_LONG_REAL));
+      #endif
     } else if (mode == M_LONG_LONG_REAL || mode == M_LONG_LONG_INT) {
-      ADDR_T pop_sp2 = A68G_SP;
-      int digits = DIGITS (mode);
-      MP_T *x = nil_mp (p, digits);
-      (void) move_mp (x, (MP_T *) item, digits);
-      exp_value = 0;
-      sign = SIGN (x[2]);
-      if (sign_mould != NO_NODE) {
-        put_sign_to_integral (sign_mould, sign);
-      }
-      x[2] = ABS (x[2]);
-      if (expo_mould != NO_NODE) {
-        long_standardise (p, x, DIGITS (mode), stag_digits, frac_digits, &exp_value);
-      }
-      str = long_sub_fixed (p, x, DIGITS (mode), mant_length, frac_digits);
-      A68G_SP = pop_sp2;
+      (void) move_mp (z, (MP_T *) item, digits);
     }
+    exp_value = 0;
+    sign = SIGN (z[2]);
+    if (sign_mould != NO_NODE) {
+      put_sign_to_integral (sign_mould, sign);
+    }
+    z[2] = ABS (z[2]);
+    if (expo_mould != NO_NODE) {
+      standardize_mp (p, z, digits, stag_digits, frac_digits, &exp_value);
+    }
+    str = sub_fixed_mp (p, z, digits,  mant_length, frac_digits);
+    A68G_SP = pop_sp2;
 // Edit and output the string.
     if (strchr (str, ERROR_CHAR) != NO_TEXT) {
       value_error (p, root, ref_file);
@@ -1275,7 +1245,7 @@ void write_real_pattern (NODE_T * p, MOID_T * mode, MOID_T * root, BYTE_T * item
     } else if (sign < 0) {
       value_sign_error (sign_mould, root, ref_file);
     }
-    put_zeroes_to_integral (p, stag_digits - (int) strlen (stag_str));
+    put_zeroes_to_integral (p, stag_digits - strlen (stag_str));
     add_string_transput_buffer (p, EDIT_BUFFER, stag_str);
     stag_str = get_transput_buffer (EDIT_BUFFER);
     mood = (MOOD_T) (DIGIT_BLANK | INSERTION_NORMAL);
@@ -1303,13 +1273,13 @@ void write_real_pattern (NODE_T * p, MOID_T * mode, MOID_T * root, BYTE_T * item
     }
 // Exponent.
     if (expo_mould != NO_NODE) {
-      A68G_INT z;
-      STATUS (&z) = INIT_MASK;
-      VALUE (&z) = exp_value;
+      A68G_INT k;
+      STATUS (&k) = INIT_MASK;
+      VALUE (&k) = exp_value;
       if (e_frame != NO_NODE) {
         write_pie_frame (e_frame, ref_file, FORMAT_E_FRAME, FORMAT_ITEM_E);
       }
-      write_integral_pattern (expo_mould, M_INT, root, (BYTE_T *) & z, ref_file);
+      write_integral_pattern (expo_mould, M_INT, root, (BYTE_T *) & k, ref_file);
     }
     A68G_SP = pop_sp;
   }
@@ -1353,60 +1323,60 @@ void write_bits_pattern (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_REF ref_
       value_error (p, mode, ref_file);
     }
   } else if (mode == M_LONG_BITS) {
-#if (A68G_LEVEL >= 3)
-    A68G_LONG_BITS *z = (A68G_LONG_BITS *) item;
+    #if (A68G_LEVEL >= 3)
+      A68G_LONG_BITS *z = (A68G_LONG_BITS *) item;
 // Establish width and radix.
-    count_zd_frames (SUB (p), &width);
-    radix = get_replicator_value (SUB_SUB (p), A68G_TRUE);
-    if (radix < 2 || radix > 16) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_RADIX, radix);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
+      count_zd_frames (SUB (p), &width);
+      radix = get_replicator_value (SUB_SUB (p), A68G_TRUE);
+      if (radix < 2 || radix > 16) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_RADIX, radix);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
 // Generate string of correct width.
-    reset_transput_buffer (EDIT_BUFFER);
-    if (!convert_radix_double (p, VALUE (z), radix, width)) {
-      errno = EDOM;
-      value_error (p, mode, ref_file);
-    }
-#else
-    int digits = DIGITS (mode);
-    MP_T *u = (MP_T *) item;
-    MP_T *v = nil_mp (p, digits);
-    MP_T *w = nil_mp (p, digits);
+      reset_transput_buffer (EDIT_BUFFER);
+      if (!convert_radix_double (p, VALUE (z), radix, width)) {
+        errno = EDOM;
+        value_error (p, mode, ref_file);
+      }
+    #else
+      int digits = DIGITS (mode);
+      MP_T *u = (MP_T *) item;
+      MP_T *v = nil_mp (p, digits);
+      MP_T *w = nil_mp (p, digits);
 // Establish width and radix.
-    count_zd_frames (SUB (p), &width);
-    radix = get_replicator_value (SUB_SUB (p), A68G_TRUE);
-    if (radix < 2 || radix > 16) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_RADIX, radix);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
+      count_zd_frames (SUB (p), &width);
+      radix = get_replicator_value (SUB_SUB (p), A68G_TRUE);
+      if (radix < 2 || radix > 16) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_RADIX, radix);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
 // Generate string of correct width.
-    reset_transput_buffer (EDIT_BUFFER);
-    if (!convert_radix_mp (p, u, radix, width, mode, v, w)) {
-      errno = EDOM;
-      value_error (p, mode, ref_file);
-    }
-#endif
+      reset_transput_buffer (EDIT_BUFFER);
+      if (!convert_radix_mp (p, u, radix, width, mode, v, w)) {
+        errno = EDOM;
+        value_error (p, mode, ref_file);
+      }
+    #endif
   } else if (mode == M_LONG_LONG_BITS) {
-#if (A68G_LEVEL <= 2)
-    int digits = DIGITS (mode);
-    MP_T *u = (MP_T *) item;
-    MP_T *v = nil_mp (p, digits);
-    MP_T *w = nil_mp (p, digits);
+    #if (A68G_LEVEL <= 2)
+      int digits = DIGITS (mode);
+      MP_T *u = (MP_T *) item;
+      MP_T *v = nil_mp (p, digits);
+      MP_T *w = nil_mp (p, digits);
 // Establish width and radix.
-    count_zd_frames (SUB (p), &width);
-    radix = get_replicator_value (SUB_SUB (p), A68G_TRUE);
-    if (radix < 2 || radix > 16) {
-      diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_RADIX, radix);
-      exit_genie (p, A68G_RUNTIME_ERROR);
-    }
+      count_zd_frames (SUB (p), &width);
+      radix = get_replicator_value (SUB_SUB (p), A68G_TRUE);
+      if (radix < 2 || radix > 16) {
+        diagnostic (A68G_RUNTIME_ERROR, p, ERROR_INVALID_RADIX, radix);
+        exit_genie (p, A68G_RUNTIME_ERROR);
+      }
 // Generate string of correct width.
-    reset_transput_buffer (EDIT_BUFFER);
-    if (!convert_radix_mp (p, u, radix, width, mode, v, w)) {
-      errno = EDOM;
-      value_error (p, mode, ref_file);
-    }
-#endif
+      reset_transput_buffer (EDIT_BUFFER);
+      if (!convert_radix_mp (p, u, radix, width, mode, v, w)) {
+        errno = EDOM;
+        value_error (p, mode, ref_file);
+      }
+    #endif
   }
 // Output the edited string.
   MOOD_T mood = (MOOD_T) (DIGIT_BLANK | INSERTION_NORMAL);
@@ -1452,21 +1422,21 @@ void genie_write_long_real_format (NODE_T * p, BYTE_T * item, A68G_REF ref_file)
   } else if (IS (p, REAL_PATTERN)) {
     write_real_pattern (p, M_LONG_REAL, M_LONG_REAL, item, ref_file);
   } else if (IS (p, COMPLEX_PATTERN)) {
-#if (A68G_LEVEL >= 3)
-    ADDR_T pop_sp = A68G_SP;
-    A68G_LONG_REAL *z = (A68G_LONG_REAL *) STACK_TOP;
-    DOUBLE_NUM_T im;
-    im.f = 0.0q;
-    PUSH_VALUE (p, im, A68G_LONG_REAL);
-    write_complex_pattern (p, M_LONG_REAL, M_LONG_COMPLEX, item, (BYTE_T *) z, ref_file);
-    A68G_SP = pop_sp;
-#else
-    ADDR_T pop_sp = A68G_SP;
-    MP_T *z = nil_mp (p, DIGITS (M_LONG_REAL));
-    z[0] = (MP_T) INIT_MASK;
-    write_complex_pattern (p, M_LONG_REAL, M_LONG_COMPLEX, item, (BYTE_T *) z, ref_file);
-    A68G_SP = pop_sp;
-#endif
+    #if (A68G_LEVEL >= 3)
+      ADDR_T pop_sp = A68G_SP;
+      A68G_LONG_REAL *z = (A68G_LONG_REAL *) STACK_TOP;
+      DOUBLE_NUM_T im;
+      im.f = 0.0q;
+      PUSH_VALUE (p, im, A68G_LONG_REAL);
+      write_complex_pattern (p, M_LONG_REAL, M_LONG_COMPLEX, item, (BYTE_T *) z, ref_file);
+      A68G_SP = pop_sp;
+    #else
+      ADDR_T pop_sp = A68G_SP;
+      MP_T *z = nil_mp (p, DIGITS (M_LONG_REAL));
+      z[0] = (MP_T) INIT_MASK;
+      write_complex_pattern (p, M_LONG_REAL, M_LONG_COMPLEX, item, (BYTE_T *) z, ref_file);
+      A68G_SP = pop_sp;
+    #endif
   } else {
     pattern_error (p, M_LONG_REAL, ATTRIBUTE (p));
   }
@@ -1525,7 +1495,7 @@ void purge_format_write (NODE_T * p, A68G_REF ref_file)
 void genie_write_standard_format (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_REF ref_file, int *formats)
 {
   errno = 0;
-  ABEND (mode == NO_MOID, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (mode == NO_MOID, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   if (mode == M_FORMAT) {
     A68G_FILE *file;
     CHECK_REF (p, ref_file, M_REF_FILE);
@@ -1584,21 +1554,21 @@ void genie_write_standard_format (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G
     } else if (IS (pat, REAL_PATTERN)) {
       write_real_pattern (pat, M_LONG_INT, M_LONG_INT, item, ref_file);
     } else if (IS (pat, COMPLEX_PATTERN)) {
-#if (A68G_LEVEL >= 3)
-      ADDR_T pop_sp = A68G_SP;
-      A68G_LONG_REAL *z = (A68G_LONG_REAL *) STACK_TOP;
-      DOUBLE_NUM_T im;
-      im.f = 0.0q;
-      PUSH_VALUE (p, im, A68G_LONG_REAL);
-      write_complex_pattern (p, M_LONG_REAL, M_LONG_COMPLEX, item, (BYTE_T *) z, ref_file);
-      A68G_SP = pop_sp;
-#else
-      ADDR_T pop_sp = A68G_SP;
-      MP_T *z = nil_mp (p, DIGITS (mode));
-      z[0] = (MP_T) INIT_MASK;
-      write_complex_pattern (pat, M_LONG_REAL, M_LONG_COMPLEX, item, (BYTE_T *) z, ref_file);
-      A68G_SP = pop_sp;
-#endif
+      #if (A68G_LEVEL >= 3)
+        ADDR_T pop_sp = A68G_SP;
+        A68G_LONG_REAL *z = (A68G_LONG_REAL *) STACK_TOP;
+        DOUBLE_NUM_T im;
+        im.f = 0.0q;
+        PUSH_VALUE (p, im, A68G_LONG_REAL);
+        write_complex_pattern (p, M_LONG_REAL, M_LONG_COMPLEX, item, (BYTE_T *) z, ref_file);
+        A68G_SP = pop_sp;
+      #else
+        ADDR_T pop_sp = A68G_SP;
+        MP_T *z = nil_mp (p, DIGITS (mode));
+        z[0] = (MP_T) INIT_MASK;
+        write_complex_pattern (pat, M_LONG_REAL, M_LONG_COMPLEX, item, (BYTE_T *) z, ref_file);
+        A68G_SP = pop_sp;
+      #endif
     } else if (IS (pat, CHOICE_PATTERN)) {
       INT_T k = mp_to_int (p, (MP_T *) item, DIGITS (mode));
       int sk;
@@ -1939,7 +1909,7 @@ void read_insertion (NODE_T * p, A68G_REF ref_file)
       genie_set (p);
     } else if (IS (p, LITERAL)) {
 // Skip characters, but don't check the literal. 
-      int len = (int) strlen (NSYMBOL (p));
+      size_t len = strlen (NSYMBOL (p));
       while (len-- && !END_OF_FILE (file)) {
         (void) read_single_char (p, ref_file);
       }
@@ -2282,7 +2252,7 @@ void read_bits_pattern (NODE_T * p, MOID_T * m, BYTE_T * item, A68G_REF ref_file
   }
   char *z = get_transput_buffer (INPUT_BUFFER);
   ASSERT (a68g_bufprt (z, (size_t) TRANSPUT_BUFFER_SIZE, "%dr", radix) >= 0);
-  set_transput_buffer_index (INPUT_BUFFER, (int) strlen (z));
+  set_transput_buffer_index (INPUT_BUFFER, strlen (z));
   read_integral_mould (NEXT_SUB (p), m, ref_file);
   genie_string_to_value (p, m, item, ref_file);
 }
