@@ -177,8 +177,8 @@ void genie_init_heap (NODE_T * p)
   A68G_GC (sweeps) = 0;
   A68G_GC (refused) = 0;
   A68G_GC (preemptive) = A68G_FALSE;
-  // Make sure we have some space for an A68 heap.
-  ABEND ((A68G (fixed_heap_pointer) + 2 * A68G (storage_overhead)) >= A68G (temp_heap_pointer), ERROR_MEMORY_FULL, __func__);
+// Make sure we have some space for an A68 heap.
+  ABEND ((A68G (fixed_heap_pointer) + 2 * A68G (storage_overhead)) >= A68G (temp_heap_pointer), ERROR_MEMORY_FULL, NO_TEXT);
   A68G_HP = A68G (fixed_heap_pointer);
   A68G (heap_is_fluid) = A68G_FALSE;
 // Assign handle space.
@@ -388,7 +388,7 @@ void defragment_heap (void)
   }
 // There can be no uncoloured allocated handle.
   for (z = A68G_GC (busy_handles); z != NO_HANDLE; FORWARD (z)) {
-    ABEND (!(STATUS_TEST (z, COLOUR_MASK)) && !(STATUS_TEST (z, BLOCK_GC_MASK)), ERROR_INTERNAL_CONSISTENCY, __func__);
+    ABEND (!(STATUS_TEST (z, COLOUR_MASK)) && !(STATUS_TEST (z, BLOCK_GC_MASK)), ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   }
 // Defragment the heap.
   A68G_HP = A68G (fixed_heap_pointer);
@@ -403,7 +403,7 @@ void defragment_heap (void)
     STATUS_CLEAR (z, (COLOUR_MASK | COOKIE_MASK));
     POINTER (z) = dst;
     A68G_HP += (SIZE (z));
-    ABEND (A68G_HP % A68G_ALIGNMENT != 0, ERROR_ALIGNMENT, __func__);
+    ABEND (A68G_HP % A68G_ALIGNMENT != 0, ERROR_ALIGNMENT, NO_TEXT);
   }
 }
 
@@ -499,7 +499,7 @@ A68G_HANDLE *give_handle (NODE_T * p, MOID_T * a68m)
 
 A68G_REF heap_generator (NODE_T * p, MOID_T * mode, size_t size)
 {
-  ABEND (size < 0, ERROR_INVALID_SIZE, __func__);
+  ABEND (size < 0, ERROR_INVALID_SIZE, NO_TEXT);
   size = A68G_ALIGN (size);
   if (heap_available () >= size) {
     A68G_REF z;
@@ -511,9 +511,9 @@ A68G_REF heap_generator (NODE_T * p, MOID_T * mode, size_t size)
     FILL (POINTER (x), 0, size);
     REF_SCOPE (&z) = PRIMAL_SCOPE;
     REF_HANDLE (&z) = x;
-    ABEND (((size_t) ADDRESS (&z)) % A68G_ALIGNMENT != 0, ERROR_ALIGNMENT, __func__);
+    ABEND (((size_t) ADDRESS (&z)) % A68G_ALIGNMENT != 0, ERROR_ALIGNMENT, NO_TEXT);
     A68G_HP += size;
-    // Raise a flag for a preemptive sweep at a convenient moment.
+// Raise a flag for a preemptive sweep at a convenient moment.
     if (heap_available () < (A68G (storage_overhead) + size) || A68G_GC (free_handles) < 100) {
       // Emergency break.
       A68G_GC (preemptive) = A68G_TRUE;
@@ -782,7 +782,7 @@ void genie_generator_internal (NODE_T * p, MOID_T * ref_mode, TAG_T * tag, LEAP_
     name = heap_generator (p, mode, SIZE (mode));
     REF_SCOPE (&name) = PRIMAL_SCOPE;
   } else {
-    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   }
   if (HAS_ROWS (mode)) {
     ADDR_T cur_sp = sp;
