@@ -353,7 +353,7 @@ TAG_T *find_tag (TABLE_T * table, int a, char *name)
     } else if (a == LABEL) {
       s = LABELS (table);
     } else {
-      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+      ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
     }
     for (; s != NO_TAG; FORWARD (s)) {
       if (strcmp (NSYMBOL (NODE (s)), name) == 0) {
@@ -1152,30 +1152,6 @@ BOOL_T check_initialisation (NODE_T * p, BYTE_T * w, MOID_T * q, BOOL_T * result
       recognised = A68G_TRUE;
       break;
     }
-#if (A68G_LEVEL >= 3)
-  case MODE_LONG_INT:
-  case MODE_LONG_BITS: {
-      A68G_LONG_INT *z = (A68G_LONG_INT *) w;
-      initialised = INITIALISED (z);
-      recognised = A68G_TRUE;
-      break;
-    }
-  case MODE_LONG_REAL: {
-      A68G_LONG_REAL *z = (A68G_LONG_REAL *) w;
-      initialised = INITIALISED (z);
-      recognised = A68G_TRUE;
-      break;
-    }
-#else
-  case MODE_LONG_INT:
-  case MODE_LONG_REAL:
-  case MODE_LONG_BITS: {
-      MP_T *z = (MP_T *) w;
-      initialised = (BOOL_T) ((unt) MP_STATUS (z) & INIT_MASK);
-      recognised = A68G_TRUE;
-      break;
-    }
-#endif
   case MODE_LONG_LONG_INT:
   case MODE_LONG_LONG_REAL:
   case MODE_LONG_LONG_BITS: {
@@ -1253,6 +1229,30 @@ BOOL_T check_initialisation (NODE_T * p, BYTE_T * w, MOID_T * q, BOOL_T * result
       initialised = INITIALISED (z);
       recognised = A68G_TRUE;
     }
+  #if (A68G_LEVEL >= 3)
+    case MODE_LONG_INT:
+    case MODE_LONG_BITS: {
+        A68G_LONG_INT *z = (A68G_LONG_INT *) w;
+        initialised = INITIALISED (z);
+        recognised = A68G_TRUE;
+        break;
+      }
+    case MODE_LONG_REAL: {
+        A68G_LONG_REAL *z = (A68G_LONG_REAL *) w;
+        initialised = INITIALISED (z);
+        recognised = A68G_TRUE;
+        break;
+      }
+  #else
+    case MODE_LONG_INT:
+    case MODE_LONG_REAL:
+    case MODE_LONG_BITS: {
+        MP_T *z = (MP_T *) w;
+        initialised = (BOOL_T) ((unt) MP_STATUS (z) & INIT_MASK);
+        recognised = A68G_TRUE;
+        break;
+      }
+  #endif
   }
   if (result != NO_BOOL) {
     *result = initialised;
@@ -1510,23 +1510,23 @@ void show_stack_frame (FILE_T f, NODE_T * p, ADDR_T a68g_link, int *printed)
   if (p != NO_NODE) {
     TABLE_T *q = TABLE (p);
     intro_frame (f, p, a68g_link, printed);
-#if (A68G_LEVEL >= 3)
-    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "Dynamic link=frame(%llu), static link=frame(%llu), parameters=frame(%llu)", FRAME_DYNAMIC_LINK (a68g_link), FRAME_STATIC_LINK (a68g_link), FRAME_PARAMETERS (a68g_link)) >= 0);
-    WRITELN (A68G_STDOUT, A68G (output_line));
+    #if (A68G_LEVEL >= 3)
+      ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "Dynamic link=frame(%llu), static link=frame(%llu), parameters=frame(%llu)", FRAME_DYNAMIC_LINK (a68g_link), FRAME_STATIC_LINK (a68g_link), FRAME_PARAMETERS (a68g_link)) >= 0);
+      WRITELN (A68G_STDOUT, A68G (output_line));
 #else
-    ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "Dynamic link=frame(%u), static link=frame(%u), parameters=frame(%u)", FRAME_DYNAMIC_LINK (a68g_link), FRAME_STATIC_LINK (a68g_link), FRAME_PARAMETERS (a68g_link)) >= 0);
-    WRITELN (A68G_STDOUT, A68G (output_line));
-#endif
+      ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "Dynamic link=frame(%u), static link=frame(%u), parameters=frame(%u)", FRAME_DYNAMIC_LINK (a68g_link), FRAME_STATIC_LINK (a68g_link), FRAME_PARAMETERS (a68g_link)) >= 0);
+      WRITELN (A68G_STDOUT, A68G (output_line));
+    #endif
     ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "Procedure frame=%s", (FRAME_PROC_FRAME (a68g_link) ? "yes" : "no")) >= 0);
     WRITELN (A68G_STDOUT, A68G (output_line));
-#if defined (BUILD_PARALLEL_CLAUSE)
-    if (pthread_equal (FRAME_THREAD_ID (a68g_link), A68G_PAR (main_thread_id)) != 0) {
-      ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "In main thread") >= 0);
-    } else {
-      ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "Not in main thread") >= 0);
-    }
-    WRITELN (A68G_STDOUT, A68G (output_line));
-#endif
+    #if defined (BUILD_PARALLEL_CLAUSE)
+      if (pthread_equal (FRAME_THREAD_ID (a68g_link), A68G_PAR (main_thread_id)) != 0) {
+        ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "In main thread") >= 0);
+      } else {
+        ASSERT (a68g_bufprt (A68G (output_line), SNPRINTF_SIZE, "Not in main thread") >= 0);
+      }
+      WRITELN (A68G_STDOUT, A68G (output_line));
+    #endif
     show_frame_items (f, p, a68g_link, IDENTIFIERS (q), IDENTIFIER);
     show_frame_items (f, p, a68g_link, OPERATORS (q), OPERATOR);
     show_frame_items (f, p, a68g_link, ANONYMOUS (q), ANONYMOUS);
