@@ -269,7 +269,7 @@ FILE_T open_physical_file (NODE_T * p, A68G_REF ref_file, int flags, mode_t perm
 {
   BOOL_T reading = (flags & ~O_BINARY) == A68G_READ_ACCESS;
   BOOL_T writing = (flags & ~O_BINARY) == A68G_WRITE_ACCESS;
-  ABEND (reading == writing, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (reading == writing, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   CHECK_REF (p, ref_file, M_REF_FILE);
   A68G_FILE *file = FILE_DEREF (&ref_file);
   CHECK_INIT (p, INITIALISED (file), M_FILE);
@@ -293,6 +293,10 @@ FILE_T open_physical_file (NODE_T * p, A68G_REF ref_file, int flags, mode_t perm
     } else {
       BUFFER tfilename;
       BUFCLR (tfilename);
+      BOOL_T write_mood = (flags & A68G_WRITE_ACCESS) != 0;
+      if (write_mood) {
+        flags |= (O_CREAT | O_TRUNC);
+      }
       if (!a68g_mkstemp (tfilename, flags, permissions)) {
         diagnostic (A68G_RUNTIME_ERROR, p, ERROR_FILE_NO_TEMP);
         exit_genie (p, A68G_RUNTIME_ERROR);
@@ -314,9 +318,24 @@ FILE_T open_physical_file (NODE_T * p, A68G_REF ref_file, int flags, mode_t perm
     A68G_REF ref_filename = IDENTIFICATION (file);
     CHECK_REF (p, ref_filename, M_ROWS);
     char *filename = DEREF (char, &ref_filename);
+    BOOL_T write_mood = (flags & A68G_WRITE_ACCESS) != 0;
+    if (write_mood) {
+      // A68G creates a file when it does not exist.
+      flags |= O_CREAT;
+    }
+    if (APPEND (file)) {
+      // Append to the end upon opening for writing.
+      if (write_mood) {
+        flags |= O_APPEND;
+      }
+      APPEND (file) = A68G_FALSE;
+    } else if (write_mood) {
+      // Empty a file upon opening for writing.
+      flags |= O_TRUNC;
+    }
     if (OPEN_EXCLUSIVE (file)) {
-// Establishing requires that the file does not exist.
-      if (flags == (A68G_WRITE_ACCESS)) {
+      // Require that the file be non-existent.
+      if (write_mood) {
         flags |= O_EXCL;
       }
       OPEN_EXCLUSIVE (file) = A68G_FALSE;
@@ -462,96 +481,96 @@ BOOL_T genie_string_to_value_internal (NODE_T * p, MOID_T * m, char *a, BYTE_T *
       return A68G_FALSE;
     }
   }
-#if (A68G_LEVEL >= 3)
-  if (m == M_LONG_INT) {
-    A68G_LONG_INT *z = (A68G_LONG_INT *) item;
-    if (string_to_double_int (p, z, a) == A68G_FALSE) {
-      return A68G_FALSE;
-    }
-    STATUS (z) = INIT_MASK;
-    return A68G_TRUE;
-  }
-  if (m == M_LONG_REAL) {
-    A68G_LONG_REAL *z = (A68G_LONG_REAL *) item;
-    char *end;
-//  VALUE (z).f = strtoflt128 (a, &end);
-    VALUE (z).f = string_to_double (a, &end);
-    MATH_RTE (p, errno != 0, M_LONG_REAL, ERROR_MATH);
-    if (end[0] == NULL_CHAR && errno == 0) {
+  #if (A68G_LEVEL >= 3)
+    if (m == M_LONG_INT) {
+      A68G_LONG_INT *z = (A68G_LONG_INT *) item;
+      if (string_to_double_int (p, z, a) == A68G_FALSE) {
+        return A68G_FALSE;
+      }
       STATUS (z) = INIT_MASK;
       return A68G_TRUE;
-    } else {
-      return A68G_FALSE;
     }
-  }
-  if (m == M_LONG_BITS) {
-    A68G_LONG_BITS *z = (A68G_LONG_BITS *) item;
-    int ret = A68G_TRUE;
-    DOUBLE_NUM_T b;
-    set_lw (b, 0x0);
-    if (a[0] == FLIP_CHAR || a[0] == FLOP_CHAR) {
-// [] BOOL denotation is "TTFFFFTFT ...".
-      if (strlen (a) > (size_t) A68G_LONG_BITS_WIDTH) {
-        errno = ERANGE;
-        ret = A68G_FALSE;
+    if (m == M_LONG_REAL) {
+      A68G_LONG_REAL *z = (A68G_LONG_REAL *) item;
+      char *end;
+//  VALUE (z).f = strtoflt128 (a, &end);
+      VALUE (z).f = string_to_double (a, &end);
+      MATH_RTE (p, errno != 0, M_LONG_REAL, ERROR_MATH);
+      if (end[0] == NULL_CHAR && errno == 0) {
+        STATUS (z) = INIT_MASK;
+        return A68G_TRUE;
       } else {
-        int n = 1;
-        UNSIGNED_T k = 0x1;
-        for (INT_T j = (INT_T) strlen (a) - 1; j >= 0; j--) {
-          if (a[j] == FLIP_CHAR) {
-            if (n <= A68G_LONG_BITS_WIDTH / 2) {
-              LW (b) |= k;
-            } else {
-              HW (b) |= k;
+        return A68G_FALSE;
+      }
+    }
+    if (m == M_LONG_BITS) {
+      A68G_LONG_BITS *z = (A68G_LONG_BITS *) item;
+      int ret = A68G_TRUE;
+      DOUBLE_NUM_T b;
+      set_lw (b, 0x0);
+      if (a[0] == FLIP_CHAR || a[0] == FLOP_CHAR) {
+// [] BOOL denotation is "TTFFFFTFT ...".
+        if (strlen (a) > (size_t) A68G_LONG_BITS_WIDTH) {
+          errno = ERANGE;
+          ret = A68G_FALSE;
+        } else {
+          int n = 1;
+          UNSIGNED_T k = 0x1;
+          for (INT_T j = (INT_T) strlen (a) - 1; j >= 0; j--) {
+            if (a[j] == FLIP_CHAR) {
+              if (n <= A68G_LONG_BITS_WIDTH / 2) {
+                LW (b) |= k;
+              } else {
+                HW (b) |= k;
+              }
+            } else if (a[j] != FLOP_CHAR) {
+              ret = A68G_FALSE;
             }
-          } else if (a[j] != FLOP_CHAR) {
-            ret = A68G_FALSE;
+            k <<= 1;
           }
-          k <<= 1;
         }
-      }
-      VALUE (z) = b;
-    } else {
-// BITS denotation.
-      VALUE (z) = double_strtou (p, a);
-    }
-    return ret;
-  }
-#else
-  if (m == M_LONG_BITS || m == M_LONG_LONG_BITS) {
-    int digits = DIGITS (m);
-    int status = A68G_TRUE;
-    ADDR_T pop_sp = A68G_SP;
-    MP_T *z = (MP_T *) item;
-    if (a[0] == FLIP_CHAR || a[0] == FLOP_CHAR) {
-// [] BOOL denotation is "TTFFFFTFT ...".
-      if (strlen (a) > (size_t) A68G_BITS_WIDTH) {
-        errno = ERANGE;
-        status = A68G_FALSE;
+        VALUE (z) = b;
       } else {
-        MP_T *w = lit_mp (p, 1, 0, digits);
-        SET_MP_ZERO (z, digits);
-        for (INT_T j = (INT_T) strlen (a) - 1; j >= 0; j--) {
-          if (a[j] == FLIP_CHAR) {
-            (void) add_mp (p, z, z, w, digits);
-          } else if (a[j] != FLOP_CHAR) {
-            status = A68G_FALSE;
-          }
-          (void) mul_mp_digit (p, w, w, (MP_T) 2, digits);
-        }
+// BITS denotation.
+        VALUE (z) = double_strtou (p, a);
       }
-    } else {
+      return ret;
+    }
+  #else
+    if (m == M_LONG_BITS || m == M_LONG_LONG_BITS) {
+      int digits = DIGITS (m);
+      int status = A68G_TRUE;
+      ADDR_T pop_sp = A68G_SP;
+      MP_T *z = (MP_T *) item;
+      if (a[0] == FLIP_CHAR || a[0] == FLOP_CHAR) {
+// [] BOOL denotation is "TTFFFFTFT ...".
+        if (strlen (a) > (size_t) A68G_BITS_WIDTH) {
+          errno = ERANGE;
+          status = A68G_FALSE;
+        } else {
+          MP_T *w = lit_mp (p, 1, 0, digits);
+          SET_MP_ZERO (z, digits);
+          for (INT_T j = (INT_T) strlen (a) - 1; j >= 0; j--) {
+            if (a[j] == FLIP_CHAR) {
+              (void) add_mp (p, z, z, w, digits);
+            } else if (a[j] != FLOP_CHAR) {
+              status = A68G_FALSE;
+            }
+            (void) mul_mp_digit (p, w, w, (MP_T) 2, digits);
+          }
+        }
+      } else {
 // BITS denotation is also allowed.
-      mp_strtou (p, z, a, m);
+        mp_strtou (p, z, a, m);
+      }
+      A68G_SP = pop_sp;
+      if (errno != 0 || status == A68G_FALSE) {
+        return A68G_FALSE;
+      }
+      MP_STATUS (z) = (MP_T) INIT_MASK;
+      return A68G_TRUE;
     }
-    A68G_SP = pop_sp;
-    if (errno != 0 || status == A68G_FALSE) {
-      return A68G_FALSE;
-    }
-    MP_STATUS (z) = (MP_T) INIT_MASK;
-    return A68G_TRUE;
-  }
-#endif
+  #endif
   if (m == M_LONG_INT || m == M_LONG_LONG_INT) {
     int digits = DIGITS (m);
     MP_T *z = (MP_T *) item;
@@ -852,79 +871,79 @@ void genie_value_to_string (NODE_T * p, MOID_T * moid, BYTE_T * item, int mod)
     }
     return;
   }
-#if (A68G_LEVEL >= 3)
-  if (moid == M_LONG_INT) {
-    A68G_LONG_INT *z = (A68G_LONG_INT *) item;
-    PUSH_UNION (p, M_LONG_INT);
-    PUSH (p, z, SIZE (M_LONG_INT));
-    INCREMENT_STACK_POINTER (p, SIZE (M_NUMBER) - (A68G_UNION_SIZE + SIZE (M_LONG_INT)));
-    if (mod == FORMAT_ITEM_G) {
-      PUSH_VALUE (p, A68G_LONG_WIDTH + 1, A68G_INT);
-      genie_whole (p);
-    } else if (mod == FORMAT_ITEM_H) {
+  #if (A68G_LEVEL >= 3)
+    if (moid == M_LONG_INT) {
+      A68G_LONG_INT *z = (A68G_LONG_INT *) item;
+      PUSH_UNION (p, M_LONG_INT);
+      PUSH (p, z, SIZE (M_LONG_INT));
+      INCREMENT_STACK_POINTER (p, SIZE (M_NUMBER) - (A68G_UNION_SIZE + SIZE (M_LONG_INT)));
+      if (mod == FORMAT_ITEM_G) {
+        PUSH_VALUE (p, A68G_LONG_WIDTH + 1, A68G_INT);
+        genie_whole (p);
+      } else if (mod == FORMAT_ITEM_H) {
+        PUSH_VALUE (p, A68G_LONG_REAL_WIDTH + A68G_LONG_EXP_WIDTH + 4, A68G_INT);
+        PUSH_VALUE (p, A68G_LONG_REAL_WIDTH - 1, A68G_INT);
+        PUSH_VALUE (p, A68G_LONG_EXP_WIDTH + 1, A68G_INT);
+        PUSH_VALUE (p, 3, A68G_INT);
+        genie_real (p);
+      }
+      return;
+    }
+    if (moid == M_LONG_REAL) {
+      A68G_LONG_REAL *z = (A68G_LONG_REAL *) item;
+      PUSH_UNION (p, M_LONG_REAL);
+      PUSH_VALUE (p, VALUE (z), A68G_LONG_REAL);
+      INCREMENT_STACK_POINTER (p, SIZE (M_NUMBER) - (A68G_UNION_SIZE + SIZE (M_LONG_REAL)));
       PUSH_VALUE (p, A68G_LONG_REAL_WIDTH + A68G_LONG_EXP_WIDTH + 4, A68G_INT);
       PUSH_VALUE (p, A68G_LONG_REAL_WIDTH - 1, A68G_INT);
       PUSH_VALUE (p, A68G_LONG_EXP_WIDTH + 1, A68G_INT);
-      PUSH_VALUE (p, 3, A68G_INT);
-      genie_real (p);
+      if (mod == FORMAT_ITEM_G) {
+        genie_float (p);
+      } else if (mod == FORMAT_ITEM_H) {
+        PUSH_VALUE (p, 3, A68G_INT);
+        genie_real (p);
+      }
+      return;
     }
-    return;
-  }
-  if (moid == M_LONG_REAL) {
-    A68G_LONG_REAL *z = (A68G_LONG_REAL *) item;
-    PUSH_UNION (p, M_LONG_REAL);
-    PUSH_VALUE (p, VALUE (z), A68G_LONG_REAL);
-    INCREMENT_STACK_POINTER (p, SIZE (M_NUMBER) - (A68G_UNION_SIZE + SIZE (M_LONG_REAL)));
-    PUSH_VALUE (p, A68G_LONG_REAL_WIDTH + A68G_LONG_EXP_WIDTH + 4, A68G_INT);
-    PUSH_VALUE (p, A68G_LONG_REAL_WIDTH - 1, A68G_INT);
-    PUSH_VALUE (p, A68G_LONG_EXP_WIDTH + 1, A68G_INT);
-    if (mod == FORMAT_ITEM_G) {
-      genie_float (p);
-    } else if (mod == FORMAT_ITEM_H) {
-      PUSH_VALUE (p, 3, A68G_INT);
-      genie_real (p);
-    }
-    return;
-  }
-  if (moid == M_LONG_BITS) {
-    A68G_LONG_BITS *z = (A68G_LONG_BITS *) item;
-    char *s = stack_string (p, 8 + A68G_LONG_BITS_WIDTH);
-    int n = 0;
-    for (int w = 0; w <= 1; w++) {
-      UNSIGNED_T bit = D_SIGN;
-      for (int j = 0; j < A68G_BITS_WIDTH; j++) {
-        if (w == 0) {
-          s[n] = (char) ((HW (VALUE (z)) & bit) ? FLIP_CHAR : FLOP_CHAR);
-        } else {
-          s[n] = (char) ((LW (VALUE (z)) & bit) ? FLIP_CHAR : FLOP_CHAR);
+    if (moid == M_LONG_BITS) {
+      A68G_LONG_BITS *z = (A68G_LONG_BITS *) item;
+      char *s = stack_string (p, 8 + A68G_LONG_BITS_WIDTH);
+      int n = 0;
+      for (int w = 0; w <= 1; w++) {
+        UNSIGNED_T bit = D_SIGN;
+        for (int j = 0; j < A68G_BITS_WIDTH; j++) {
+          if (w == 0) {
+            s[n] = (char) ((HW (VALUE (z)) & bit) ? FLIP_CHAR : FLOP_CHAR);
+          } else {
+            s[n] = (char) ((LW (VALUE (z)) & bit) ? FLIP_CHAR : FLOP_CHAR);
+          }
+          bit >>= 1;
+          n++;
         }
-        bit >>= 1;
-        n++;
       }
+      s[n] = NULL_CHAR;
+      return;
     }
-    s[n] = NULL_CHAR;
-    return;
-  }
-#else
-  if (moid == M_LONG_BITS || moid == M_LONG_LONG_BITS) {
-    int bits = get_mp_bits_width (moid), word = get_mp_bits_words (moid);
-    int pos = bits;
-    char *str = stack_string (p, 8 + bits);
-    ADDR_T pop_sp = A68G_SP;
-    unt *row = stack_mp_bits (p, (MP_T *) item, moid);
-    str[pos--] = NULL_CHAR;
-    while (pos >= 0) {
-      unt bit = 0x1;
-      for (int j = 0; j < MP_BITS_BITS && pos >= 0; j++) {
-        str[pos--] = (char) ((row[word - 1] & bit) ? FLIP_CHAR : FLOP_CHAR);
-        bit <<= 1;
+  #else
+    if (moid == M_LONG_BITS || moid == M_LONG_LONG_BITS) {
+      int bits = get_mp_bits_width (moid), word = get_mp_bits_words (moid);
+      int pos = bits;
+      char *str = stack_string (p, 8 + bits);
+      ADDR_T pop_sp = A68G_SP;
+      unt *row = stack_mp_bits (p, (MP_T *) item, moid);
+      str[pos--] = NULL_CHAR;
+      while (pos >= 0) {
+        unt bit = 0x1;
+        for (int j = 0; j < MP_BITS_BITS && pos >= 0; j++) {
+          str[pos--] = (char) ((row[word - 1] & bit) ? FLIP_CHAR : FLOP_CHAR);
+          bit <<= 1;
+        }
+        word--;
       }
-      word--;
+      A68G_SP = pop_sp;
+      return;
     }
-    A68G_SP = pop_sp;
-    return;
-  }
-#endif
+  #endif
   if (moid == M_LONG_INT) {
     MP_T *z = (MP_T *) item;
     PUSH_UNION (p, M_LONG_INT);
@@ -1029,7 +1048,7 @@ void genie_value_to_string (NODE_T * p, MOID_T * moid, BYTE_T * item, int mod)
 void genie_write_standard (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_REF ref_file)
 {
   errno = 0;
-  ABEND (mode == NO_MOID, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (mode == NO_MOID, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   if (mode == M_PROC_REF_FILE_VOID) {
     genie_call_proc_ref_file_void (p, ref_file, *(A68G_PROCEDURE *) item);
   } else if (mode == M_FORMAT) {
@@ -1206,15 +1225,15 @@ void genie_read_bin_standard (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_REF
     ASSERT (io_read (FD (f), &(VALUE (z)), sizeof (VALUE (z))) != -1);
     STATUS (z) = INIT_MASK;
   } else if (mode == M_LONG_INT) {
-#if (A68G_LEVEL >= 3)
+  #if (A68G_LEVEL >= 3)
     A68G_LONG_INT *z = (A68G_LONG_INT *) item;
     ASSERT (io_read (FD (f), &(VALUE (z)), sizeof (VALUE (z))) != -1);
     STATUS (z) = INIT_MASK;
-#else
+  #else
     MP_T *z = (MP_T *) item;
     ASSERT (io_read (FD (f), z, (size_t) SIZE (mode)) != -1);
     MP_STATUS (z) = (MP_T) INIT_MASK;
-#endif
+  #endif
   } else if (mode == M_LONG_LONG_INT) {
     MP_T *z = (MP_T *) item;
     ASSERT (io_read (FD (f), z, (size_t) SIZE (mode)) != -1);
@@ -1224,15 +1243,15 @@ void genie_read_bin_standard (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_REF
     ASSERT (io_read (FD (f), &(VALUE (z)), sizeof (VALUE (z))) != -1);
     STATUS (z) = INIT_MASK;
   } else if (mode == M_LONG_REAL) {
-#if (A68G_LEVEL >= 3)
-    A68G_LONG_REAL *z = (A68G_LONG_REAL *) item;
-    ASSERT (io_read (FD (f), &(VALUE (z)), sizeof (VALUE (z))) != -1);
-    STATUS (z) = INIT_MASK;
-#else
-    MP_T *z = (MP_T *) item;
-    ASSERT (io_read (FD (f), z, (size_t) SIZE (mode)) != -1);
-    MP_STATUS (z) = (MP_T) INIT_MASK;
-#endif
+    #if (A68G_LEVEL >= 3)
+      A68G_LONG_REAL *z = (A68G_LONG_REAL *) item;
+      ASSERT (io_read (FD (f), &(VALUE (z)), sizeof (VALUE (z))) != -1);
+      STATUS (z) = INIT_MASK;
+    #else
+      MP_T *z = (MP_T *) item;
+      ASSERT (io_read (FD (f), z, (size_t) SIZE (mode)) != -1);
+      MP_STATUS (z) = (MP_T) INIT_MASK;
+    #endif
   } else if (mode == M_LONG_LONG_REAL) {
     MP_T *z = (MP_T *) item;
     ASSERT (io_read (FD (f), z, (size_t) SIZE (mode)) != -1);
@@ -1250,15 +1269,15 @@ void genie_read_bin_standard (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_REF
     ASSERT (io_read (FD (f), &(VALUE (z)), sizeof (VALUE (z))) != -1);
     STATUS (z) = INIT_MASK;
   } else if (mode == M_LONG_BITS) {
-#if (A68G_LEVEL >= 3)
-    A68G_LONG_BITS *z = (A68G_LONG_BITS *) item;
-    ASSERT (io_read (FD (f), &(VALUE (z)), sizeof (VALUE (z))) != -1);
-    STATUS (z) = INIT_MASK;
-#else
-    MP_T *z = (MP_T *) item;
-    ASSERT (io_read (FD (f), z, (size_t) SIZE (mode)) != -1);
-    MP_STATUS (z) = (MP_T) INIT_MASK;
-#endif
+    #if (A68G_LEVEL >= 3)
+      A68G_LONG_BITS *z = (A68G_LONG_BITS *) item;
+      ASSERT (io_read (FD (f), &(VALUE (z)), sizeof (VALUE (z))) != -1);
+      STATUS (z) = INIT_MASK;
+    #else
+      MP_T *z = (MP_T *) item;
+      ASSERT (io_read (FD (f), z, (size_t) SIZE (mode)) != -1);
+      MP_STATUS (z) = (MP_T) INIT_MASK;
+    #endif
   } else if (mode == M_LONG_LONG_BITS) {
     MP_T *z = (MP_T *) item;
     ASSERT (io_read (FD (f), z, (size_t) SIZE (mode)) != -1);
@@ -1397,21 +1416,21 @@ void genie_write_bin_standard (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_RE
   } else if (mode == M_INT) {
     ASSERT (io_write (FD (f), &(VALUE ((A68G_INT *) item)), sizeof (VALUE ((A68G_INT *) item))) != -1);
   } else if (mode == M_LONG_INT) {
-#if (A68G_LEVEL >= 3)
-    ASSERT (io_write (FD (f), &(VALUE ((A68G_LONG_INT *) item)), sizeof (VALUE ((A68G_LONG_INT *) item))) != -1);
-#else
-    ASSERT (io_write (FD (f), (MP_T *) item, (size_t) SIZE (mode)) != -1);
-#endif
+    #if (A68G_LEVEL >= 3)
+      ASSERT (io_write (FD (f), &(VALUE ((A68G_LONG_INT *) item)), sizeof (VALUE ((A68G_LONG_INT *) item))) != -1);
+    #else
+      ASSERT (io_write (FD (f), (MP_T *) item, (size_t) SIZE (mode)) != -1);
+    #endif
   } else if (mode == M_LONG_LONG_INT) {
     ASSERT (io_write (FD (f), (MP_T *) item, (size_t) SIZE (mode)) != -1);
   } else if (mode == M_REAL) {
     ASSERT (io_write (FD (f), &(VALUE ((A68G_REAL *) item)), sizeof (VALUE ((A68G_REAL *) item))) != -1);
   } else if (mode == M_LONG_REAL) {
-#if (A68G_LEVEL >= 3)
-    ASSERT (io_write (FD (f), &(VALUE ((A68G_LONG_REAL *) item)), sizeof (VALUE ((A68G_LONG_REAL *) item))) != -1);
-#else
-    ASSERT (io_write (FD (f), (MP_T *) item, (size_t) SIZE (mode)) != -1);
-#endif
+    #if (A68G_LEVEL >= 3)
+      ASSERT (io_write (FD (f), &(VALUE ((A68G_LONG_REAL *) item)), sizeof (VALUE ((A68G_LONG_REAL *) item))) != -1);
+    #else
+      ASSERT (io_write (FD (f), (MP_T *) item, (size_t) SIZE (mode)) != -1);
+    #endif
   } else if (mode == M_LONG_LONG_REAL) {
     ASSERT (io_write (FD (f), (MP_T *) item, (size_t) SIZE (mode)) != -1);
   } else if (mode == M_BOOL) {
@@ -1421,11 +1440,11 @@ void genie_write_bin_standard (NODE_T * p, MOID_T * mode, BYTE_T * item, A68G_RE
   } else if (mode == M_BITS) {
     ASSERT (io_write (FD (f), &(VALUE ((A68G_BITS *) item)), sizeof (VALUE ((A68G_BITS *) item))) != -1);
   } else if (mode == M_LONG_BITS) {
-#if (A68G_LEVEL >= 3)
-    ASSERT (io_write (FD (f), &(VALUE ((A68G_LONG_BITS *) item)), sizeof (VALUE ((A68G_LONG_BITS *) item))) != -1);
-#else
-    ASSERT (io_write (FD (f), (MP_T *) item, (size_t) SIZE (mode)) != -1);
-#endif
+    #if (A68G_LEVEL >= 3)
+      ASSERT (io_write (FD (f), &(VALUE ((A68G_LONG_BITS *) item)), sizeof (VALUE ((A68G_LONG_BITS *) item))) != -1);
+    #else
+      ASSERT (io_write (FD (f), (MP_T *) item, (size_t) SIZE (mode)) != -1);
+    #endif
   } else if (mode == M_LONG_LONG_BITS) {
     ASSERT (io_write (FD (f), (MP_T *) item, (size_t) SIZE (mode)) != -1);
   } else if (mode == M_ROW_CHAR || mode == M_STRING) {
@@ -1626,46 +1645,46 @@ char *bits_to_string (NODE_T * p)
     exit_genie (p, A68G_RUNTIME_ERROR);
   }
   reset_transput_buffer (EDIT_BUFFER);
-#if (A68G_LEVEL <= 2)
-  (void) mode;
-  (void) length;
-  (void) error_chars (get_transput_buffer (EDIT_BUFFER), VALUE (&width));
-#else
-  {
-    BOOL_T ret = A68G_TRUE;
-    if (mode == M_BOOL) {
-      UNSIGNED_T z = VALUE ((A68G_BOOL *) (STACK_OFFSET (A68G_UNION_SIZE)));
-      ret = convert_radix (p, (UNSIGNED_T) z, radix, length);
-    } else if (mode == M_CHAR) {
-      INT_T z = VALUE ((A68G_CHAR *) (STACK_OFFSET (A68G_UNION_SIZE)));
-      ret = convert_radix (p, (UNSIGNED_T) z, radix, length);
-    } else if (mode == M_INT) {
-      INT_T z = VALUE ((A68G_INT *) (STACK_OFFSET (A68G_UNION_SIZE)));
-      ret = convert_radix (p, (UNSIGNED_T) z, radix, length);
-    } else if (mode == M_REAL) {
+  #if (A68G_LEVEL <= 2)
+    (void) mode;
+    (void) length;
+    (void) error_chars (get_transput_buffer (EDIT_BUFFER), VALUE (&width));
+  #else
+    {
+      BOOL_T ret = A68G_TRUE;
+      if (mode == M_BOOL) {
+        UNSIGNED_T z = VALUE ((A68G_BOOL *) (STACK_OFFSET (A68G_UNION_SIZE)));
+        ret = convert_radix (p, (UNSIGNED_T) z, radix, length);
+      } else if (mode == M_CHAR) {
+        INT_T z = VALUE ((A68G_CHAR *) (STACK_OFFSET (A68G_UNION_SIZE)));
+        ret = convert_radix (p, (UNSIGNED_T) z, radix, length);
+      } else if (mode == M_INT) {
+        INT_T z = VALUE ((A68G_INT *) (STACK_OFFSET (A68G_UNION_SIZE)));
+        ret = convert_radix (p, (UNSIGNED_T) z, radix, length);
+      } else if (mode == M_REAL) {
 // A trick to copy a REAL into an unt without truncating
-      UNSIGNED_T z;
-      memcpy (&z, (void *) &VALUE ((A68G_REAL *) (STACK_OFFSET (A68G_UNION_SIZE))), 8);
-      ret = convert_radix (p, z, radix, length);
-    } else if (mode == M_BITS) {
-      UNSIGNED_T z = VALUE ((A68G_BITS *) (STACK_OFFSET (A68G_UNION_SIZE)));
-      ret = convert_radix (p, (UNSIGNED_T) z, radix, length);
-    } else if (mode == M_LONG_INT) {
-      DOUBLE_NUM_T z = VALUE ((A68G_LONG_INT *) (STACK_OFFSET (A68G_UNION_SIZE)));
-      ret = convert_radix_double (p, z, radix, length);
-    } else if (mode == M_LONG_REAL) {
-      DOUBLE_NUM_T z = VALUE ((A68G_LONG_REAL *) (STACK_OFFSET (A68G_UNION_SIZE)));
-      ret = convert_radix_double (p, z, radix, length);
-    } else if (mode == M_LONG_BITS) {
-      DOUBLE_NUM_T z = VALUE ((A68G_LONG_BITS *) (STACK_OFFSET (A68G_UNION_SIZE)));
-      ret = convert_radix_double (p, z, radix, length);
+        UNSIGNED_T z;
+        memcpy (&z, (void *) &VALUE ((A68G_REAL *) (STACK_OFFSET (A68G_UNION_SIZE))), 8);
+        ret = convert_radix (p, z, radix, length);
+      } else if (mode == M_BITS) {
+        UNSIGNED_T z = VALUE ((A68G_BITS *) (STACK_OFFSET (A68G_UNION_SIZE)));
+        ret = convert_radix (p, (UNSIGNED_T) z, radix, length);
+      } else if (mode == M_LONG_INT) {
+        DOUBLE_NUM_T z = VALUE ((A68G_LONG_INT *) (STACK_OFFSET (A68G_UNION_SIZE)));
+        ret = convert_radix_double (p, z, radix, length);
+      } else if (mode == M_LONG_REAL) {
+        DOUBLE_NUM_T z = VALUE ((A68G_LONG_REAL *) (STACK_OFFSET (A68G_UNION_SIZE)));
+        ret = convert_radix_double (p, z, radix, length);
+      } else if (mode == M_LONG_BITS) {
+        DOUBLE_NUM_T z = VALUE ((A68G_LONG_BITS *) (STACK_OFFSET (A68G_UNION_SIZE)));
+        ret = convert_radix_double (p, z, radix, length);
+      }
+      if (ret == A68G_FALSE) {
+        errno = EDOM;
+        PRELUDE_ERROR (A68G_TRUE, p, ERROR_OUT_OF_BOUNDS, mode);
+      }
     }
-    if (ret == A68G_FALSE) {
-      errno = EDOM;
-      PRELUDE_ERROR (A68G_TRUE, p, ERROR_OUT_OF_BOUNDS, mode);
-    }
-  }
-#endif
+  #endif
   A68G_SP = pop_sp;
   return get_transput_buffer (EDIT_BUFFER);
 }
@@ -1721,17 +1740,17 @@ char *whole (NODE_T * p)
     PUSH_PRIMAL (p, VALUE (&width), INT);
     return whole (p);
   }
-#if (A68G_LEVEL >= 3)
-  if (mode == M_LONG_INT) {
-    DOUBLE_NUM_T x = VALUE ((A68G_LONG_INT *) (STACK_OFFSET (A68G_UNION_SIZE)));
-    int digits = DIGITS (M_LONG_LONG_INT);
-    PUSH_UNION (p, (void *) M_LONG_LONG_INT);
-    MP_T *z = nil_mp (p, digits);
-    (void) double_int_to_mp (p, z, x, digits);
-    PUSH_PRIMAL (p, VALUE (&width), INT);
-    return whole (p);
-  }
-#endif
+  #if (A68G_LEVEL >= 3)
+    if (mode == M_LONG_INT) {
+      DOUBLE_NUM_T x = VALUE ((A68G_LONG_INT *) (STACK_OFFSET (A68G_UNION_SIZE)));
+      int digits = DIGITS (M_LONG_LONG_INT);
+      PUSH_UNION (p, (void *) M_LONG_LONG_INT);
+      MP_T *z = nil_mp (p, digits);
+      (void) double_int_to_mp (p, z, x, digits);
+      PUSH_PRIMAL (p, VALUE (&width), INT);
+      return whole (p);
+    }
+  #endif
   if (mode == M_LONG_INT || mode == M_LONG_LONG_INT) {
     int digits = DIGITS (mode);
     MP_T *n = (MP_T *) (STACK_OFFSET (A68G_UNION_SIZE));
@@ -1776,7 +1795,7 @@ char *whole (NODE_T * p)
     A68G_SP = pop_sp;
     return s;
   }
-  ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   return NO_TEXT;
 }
 
@@ -1893,34 +1912,34 @@ char *fixed (NODE_T * p)
       return fixed (p);
     }
   }
-#if (A68G_LEVEL >= 3)
-  if (mode == M_LONG_INT) {
-    DOUBLE_NUM_T x = VALUE ((A68G_LONG_INT *) (STACK_OFFSET (A68G_UNION_SIZE)));
-    int digits = DIGITS (M_LONG_LONG_REAL);
-    PUSH_UNION (p, (void *) M_LONG_LONG_REAL);
-    MP_T *z = nil_mp (p, digits);
-    (void) double_int_to_mp (p, z, x, digits);
-    PUSH_PRIMAL (p, VALUE (&width), INT);
-    PUSH_PRIMAL (p, VALUE (&after), INT);
-    return fixed (p);
-  } else if (mode == M_LONG_REAL) {
-    DOUBLE_T x = VALUE ((A68G_LONG_REAL *) (STACK_OFFSET (A68G_UNION_SIZE))).f;
-    if (!a68g_finite_double (x)) {
-      char *s = stack_string (p, 8 + ABS (VALUE (&width)));
-      A68G_SP = pop_sp;
-      return error_chars (s, VALUE (&width));
-    } else {
-      CHECK_DOUBLE_REAL (p, x);
+  #if (A68G_LEVEL >= 3)
+    if (mode == M_LONG_INT) {
+      DOUBLE_NUM_T x = VALUE ((A68G_LONG_INT *) (STACK_OFFSET (A68G_UNION_SIZE)));
       int digits = DIGITS (M_LONG_LONG_REAL);
       PUSH_UNION (p, (void *) M_LONG_LONG_REAL);
       MP_T *z = nil_mp (p, digits);
-      (void) double_to_mp (p, z, x, A68G_DOUBLE_DIG, A68G_TRUE, digits);
+      (void) double_int_to_mp (p, z, x, digits);
       PUSH_PRIMAL (p, VALUE (&width), INT);
       PUSH_PRIMAL (p, VALUE (&after), INT);
       return fixed (p);
+    } else if (mode == M_LONG_REAL) {
+      DOUBLE_T x = VALUE ((A68G_LONG_REAL *) (STACK_OFFSET (A68G_UNION_SIZE))).f;
+      if (!a68g_finite_double (x)) {
+        char *s = stack_string (p, 8 + ABS (VALUE (&width)));
+        A68G_SP = pop_sp;
+        return error_chars (s, VALUE (&width));
+      } else {
+        CHECK_DOUBLE_REAL (p, x);
+        int digits = DIGITS (M_LONG_LONG_REAL);
+        PUSH_UNION (p, (void *) M_LONG_LONG_REAL);
+        MP_T *z = nil_mp (p, digits);
+        (void) double_to_mp (p, z, x, A68G_DOUBLE_DIG, A68G_TRUE, digits);
+        PUSH_PRIMAL (p, VALUE (&width), INT);
+        PUSH_PRIMAL (p, VALUE (&after), INT);
+        return fixed (p);
+      }
     }
-  }
-#endif
+  #endif
   if (mode == M_LONG_INT || mode == M_LONG_LONG_INT) {
     if (mode == M_LONG_INT) {
       VALUE ((A68G_UNION *) STACK_TOP) = (void *) M_LONG_REAL;
@@ -1992,7 +2011,7 @@ char *fixed (NODE_T * p)
       }
     }
   }
-  ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   return NO_TEXT;
 }
 
@@ -2090,38 +2109,38 @@ char *real (NODE_T * p)
       return real (p);
     }
   }
-#if (A68G_LEVEL >= 3)
-  if (mode == M_LONG_INT) {
-    DOUBLE_NUM_T k = VALUE ((A68G_LONG_REAL *) (STACK_OFFSET (A68G_UNION_SIZE)));
-    int digits = DIGITS (M_LONG_LONG_REAL);
-    PUSH_UNION (p, (void *) M_LONG_LONG_REAL);
-    MP_T *z = nil_mp (p, digits);
-    (void) double_int_to_mp (p, z, k, digits);
-    PUSH_PRIMAL (p, VALUE (&width), INT);
-    PUSH_PRIMAL (p, VALUE (&after), INT);
-    PUSH_PRIMAL (p, VALUE (&expo), INT);
-    PUSH_PRIMAL (p, VALUE (&frmt), INT);
-    return real (p);
-  } else if (mode == M_LONG_REAL) {
-    DOUBLE_T x = VALUE ((A68G_LONG_REAL *) (STACK_OFFSET (A68G_UNION_SIZE))).f;
-    if (!a68g_finite_double (x)) {
-      char *s = stack_string (p, 8 + ABS (VALUE (&width)));
-      A68G_SP = pop_sp;
-      return error_chars (s, VALUE (&width));
-    } else {
-      CHECK_DOUBLE_REAL (p, x);
+  #if (A68G_LEVEL >= 3)
+    if (mode == M_LONG_INT) {
+      DOUBLE_NUM_T k = VALUE ((A68G_LONG_REAL *) (STACK_OFFSET (A68G_UNION_SIZE)));
       int digits = DIGITS (M_LONG_LONG_REAL);
       PUSH_UNION (p, (void *) M_LONG_LONG_REAL);
       MP_T *z = nil_mp (p, digits);
-      (void) double_to_mp (p, z, (DOUBLE_T) x, A68G_DOUBLE_DIG, A68G_TRUE, digits);
+      (void) double_int_to_mp (p, z, k, digits);
       PUSH_PRIMAL (p, VALUE (&width), INT);
       PUSH_PRIMAL (p, VALUE (&after), INT);
       PUSH_PRIMAL (p, VALUE (&expo), INT);
       PUSH_PRIMAL (p, VALUE (&frmt), INT);
       return real (p);
+    } else if (mode == M_LONG_REAL) {
+      DOUBLE_T x = VALUE ((A68G_LONG_REAL *) (STACK_OFFSET (A68G_UNION_SIZE))).f;
+      if (!a68g_finite_double (x)) {
+        char *s = stack_string (p, 8 + ABS (VALUE (&width)));
+        A68G_SP = pop_sp;
+        return error_chars (s, VALUE (&width));
+      } else {
+        CHECK_DOUBLE_REAL (p, x);
+        int digits = DIGITS (M_LONG_LONG_REAL);
+        PUSH_UNION (p, (void *) M_LONG_LONG_REAL);
+        MP_T *z = nil_mp (p, digits);
+        (void) double_to_mp (p, z, (DOUBLE_T) x, A68G_DOUBLE_DIG, A68G_TRUE, digits);
+        PUSH_PRIMAL (p, VALUE (&width), INT);
+        PUSH_PRIMAL (p, VALUE (&after), INT);
+        PUSH_PRIMAL (p, VALUE (&expo), INT);
+        PUSH_PRIMAL (p, VALUE (&frmt), INT);
+        return real (p);
+      }
     }
-  }
-#endif
+  #endif
   if (mode == M_LONG_INT || mode == M_LONG_LONG_INT) {
     A68G_SP = pop_sp;
     if (mode == M_LONG_INT) {
@@ -2187,10 +2206,10 @@ char *real (NODE_T * p)
           }
           A68G_SP = sp1;
         }
-  //
+//
         int strwid = 8 + ABS (VALUE (&width));
         char *s = stack_string (p, strwid);
-  // Mantissa.
+// Mantissa.
         PUSH_UNION (p, mode);
         MP_DIGIT (z, 1) = (ltz ? -MP_DIGIT (z, 1) : MP_DIGIT (z, 1));
         size_t N_mp = SIZE (mode);
@@ -2199,14 +2218,14 @@ char *real (NODE_T * p)
         PUSH_VALUE (p, SIGN (VALUE (&width)) * (ABS (VALUE (&width)) - ABS (VALUE (&expo)) - 1), A68G_INT);
         PUSH_VALUE (p, VALUE (&after), A68G_INT);
         a68g_bufcpy (s, fixed (p), strwid);
-  // Exponent.
+// Exponent.
         PUSH_UNION (p, M_INT);
         PUSH_VALUE (p, q, A68G_INT);
         INCREMENT_STACK_POINTER (p, SIZE (M_NUMBER) - (A68G_UNION_SIZE + SIZE (M_INT)));
         PUSH_VALUE (p, VALUE (&expo), A68G_INT);
         (void) string_plusab_char (s, EXPONENT_CHAR, strwid);
         a68g_bufcat (s, whole (p), strwid);
-  // Recursion when error chars.
+// Recursion when error chars.
         if (VALUE (&expo) == 0 || strchr (s, ERROR_CHAR) != NO_TEXT) {
           A68G_SP = arg_sp;
           // INCREMENT_STACK_POINTER (p, SIZE (M_NUMBER));
@@ -2226,7 +2245,7 @@ char *real (NODE_T * p)
       }
     }
   }
-  ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+  ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   return NO_TEXT;
 }
 
@@ -2372,16 +2391,16 @@ A68C_TRANSPUT (long_mp_complex, long_mp_real, LONG_LONG_COMPLEX);
 
 void genie_read_line (NODE_T * p)
 {
-#if defined (HAVE_READLINE)
-  char *line = readline ("");
-  if (line != NO_TEXT && strlen (line) > 0) {
-    add_history (line);
-  }
-  PUSH_REF (p, c_to_a_string (p, line, DEFAULT_WIDTH));
-  a68g_free (line);
-#else
-  genie_read_string (p);
-  genie_stand_in (p);
-  genie_new_line (p);
-#endif
+  #if defined (HAVE_READLINE)
+    char *line = readline ("");
+    if (line != NO_TEXT && strlen (line) > 0) {
+      add_history (line);
+    }
+    PUSH_REF (p, c_to_a_string (p, line, DEFAULT_WIDTH));
+    a68g_free (line);
+  #else
+    genie_read_string (p);
+    genie_stand_in (p);
+    genie_new_line (p);
+  #endif
 }
