@@ -194,9 +194,9 @@ void genie_matrix_pinv_lim (NODE_T * p)
 // G. Strang. "Linear Algebra and its applications", 2nd edition.
 // Academic Press [1980].
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
-  A68_REAL lim;
-  POP_OBJECT (p, &lim, A68_REAL);
-  gsl_matrix *X = pop_matrix (p, A68_TRUE), *mpinv = NO_REAL_MATRIX;
+  A68G_REAL lim;
+  POP_OBJECT (p, &lim, A68G_REAL);
+  gsl_matrix *X = pop_matrix (p, A68G_TRUE), *mpinv = NO_REAL_MATRIX;
   compute_pseudo_inverse (p, &mpinv, X, VALUE (&lim));
   push_matrix (p, mpinv);
   a68g_matrix_free (mpinv);
@@ -208,7 +208,7 @@ void genie_matrix_pinv_lim (NODE_T * p)
 
 void genie_matrix_pinv (NODE_T * p)
 {
-  PUSH_VALUE (p, SMALL_EIGEN, A68_REAL);
+  PUSH_VALUE (p, SMALL_EIGEN, A68G_REAL);
   genie_matrix_pinv_lim (p);
 }
 
@@ -217,7 +217,7 @@ void genie_matrix_pinv (NODE_T * p)
 void genie_matrix_column_mean (NODE_T *p)
 {
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
-  gsl_matrix *Z = pop_matrix (p, A68_TRUE); 
+  gsl_matrix *Z = pop_matrix (p, A68G_TRUE); 
   unt M = SIZE1 (Z), N = SIZE2 (Z);
   gsl_matrix *A = gsl_matrix_calloc (M, N);
   for (int i = 0; i < N; i++) {
@@ -240,9 +240,9 @@ void genie_matrix_column_mean (NODE_T *p)
 
 void genie_left_columns (NODE_T *p)
 {
-  A68_INT k;
-  POP_OBJECT (p, &k, A68_INT);
-  gsl_matrix *X = pop_matrix (p, A68_TRUE); 
+  A68G_INT k;
+  POP_OBJECT (p, &k, A68G_INT);
+  gsl_matrix *X = pop_matrix (p, A68G_TRUE); 
   gsl_matrix *Y = left_columns (p, X, VALUE (&k));
   push_matrix (p, Y);
   a68g_matrix_free (X);
@@ -258,9 +258,9 @@ void genie_matrix_pca_cv (NODE_T * p)
 // Hence this routine might loose more significant digits than SVD.
 // On the other hand, using PCA one looks for dominant eigenvectors.
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
-  A68_REF singulars;
+  A68G_REF singulars;
   POP_REF (p, &singulars);
-  gsl_matrix *X = pop_matrix (p, A68_TRUE);
+  gsl_matrix *X = pop_matrix (p, A68G_TRUE);
   MATH_RTE (p, X == NO_REAL_MATRIX, M_ROW_ROW_REAL, "empty data matrix");
 // M samples, N features.
   unt M = SIZE1 (X), N = SIZE2 (X);
@@ -278,7 +278,7 @@ void genie_matrix_pca_cv (NODE_T * p)
   ASSERT_GSL (gsl_eigen_symmv_sort (Sv, eigens, GSL_EIGEN_SORT_ABS_DESC));
 // Yield results.
   if (!IS_NIL (singulars)) {
-    *DEREF (A68_REF, &singulars) = vector_to_row (p, Sv);
+    *DEREF (A68G_REF, &singulars) = vector_to_row (p, Sv);
   }
   push_matrix (p, eigens);
   (void) gsl_set_error_handler (save_handler);
@@ -297,10 +297,10 @@ void genie_matrix_pca_svd (NODE_T * p)
 {
 // Principal component analysis of a MxN matrix by Jacobi SVD.
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
-  A68_REF singulars;
+  A68G_REF singulars;
   POP_REF (p, &singulars);
 // X data matrix, samples in rows, features in columns
-  gsl_matrix *X = pop_matrix (p, A68_TRUE);
+  gsl_matrix *X = pop_matrix (p, A68G_TRUE);
   MATH_RTE (p, X == NO_REAL_MATRIX, M_ROW_ROW_REAL, "empty data matrix");
 // Keep X column-mean-centered.
   gsl_matrix *C = column_mean (X);
@@ -308,7 +308,7 @@ void genie_matrix_pca_svd (NODE_T * p)
   gsl_matrix *eigens = pca_svd (C, &Sv);
 // Yield results.
   if (!IS_NIL (singulars)) {
-    *DEREF (A68_REF, &singulars) = vector_to_row (p, Sv);
+    *DEREF (A68G_REF, &singulars) = vector_to_row (p, Sv);
   }
   push_matrix (p, eigens);
   (void) gsl_set_error_handler (save_handler);
@@ -329,19 +329,19 @@ void genie_matrix_pcr (NODE_T * p)
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
 // Pop arguments.
 // 'lim' is minimum relative length to first eigenvector.
-  A68_REAL lim;
-  POP_OBJECT (p, &lim, A68_REAL); 
+  A68G_REAL lim;
+  POP_OBJECT (p, &lim, A68G_REAL); 
 // 'Nc' is maximum number of eigenvectors.
-  A68_INT Nc;
-  POP_OBJECT (p, &Nc, A68_INT); 
-  A68_REF singulars;
+  A68G_INT Nc;
+  POP_OBJECT (p, &Nc, A68G_INT); 
+  A68G_REF singulars;
   POP_REF (p, &singulars);
 // Y data vector, features in a single column
-  gsl_matrix *Y = pop_matrix (p, A68_TRUE);
+  gsl_matrix *Y = pop_matrix (p, A68G_TRUE);
   MATH_RTE (p, Y == NO_REAL_MATRIX, M_ROW_ROW_REAL, "empty data matrix");
   unt My = SIZE1 (Y), Ny = SIZE2 (Y);
 // X data matrix, samples in rows, features in columns
-  gsl_matrix *X = pop_matrix (p, A68_TRUE);
+  gsl_matrix *X = pop_matrix (p, A68G_TRUE);
   MATH_RTE (p, X == NO_REAL_MATRIX, M_ROW_ROW_REAL, "empty data matrix");
   unt Mx = SIZE1 (X), Nx = SIZE2 (X);
 // Catch wrong calls.
@@ -380,7 +380,7 @@ void genie_matrix_pcr (NODE_T * p)
   a68g_dgemm (SELF, SELF, 1.0, z, Y, 0.0, &beta);
 // Yield results.
   if (!IS_NIL (singulars)) {
-    *DEREF (A68_REF, &singulars) = vector_to_row (p, Sv);
+    *DEREF (A68G_REF, &singulars) = vector_to_row (p, Sv);
   }
   push_matrix (p, beta);
   (void) gsl_set_error_handler (save_handler);
@@ -404,13 +404,13 @@ void genie_matrix_ols (NODE_T *p)
 // TLS relates to PLS as OLS relates to PCR.
 // Note that X is an MxN matrix and Y, β are Nx1 column vectors.
 // OLS can implemented (inefficiently) as PCR with maximum number of singular values:
-//  PUSH_VALUE (p, 0.0, A68_REAL);
-//  PUSH_VALUE (p, 0, A68_INT);
+//  PUSH_VALUE (p, 0.0, A68G_REAL);
+//  PUSH_VALUE (p, 0, A68G_INT);
 //  genie_matrix_pcr (p);
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
 // X and Y matrices.
-  gsl_matrix *Y = pop_matrix (p, A68_TRUE);
-  gsl_matrix *X = pop_matrix (p, A68_TRUE);
+  gsl_matrix *Y = pop_matrix (p, A68G_TRUE);
+  gsl_matrix *X = pop_matrix (p, A68G_TRUE);
 // Compute β = X⁻¹ * Y.
   gsl_matrix *mpinv = NO_REAL_MATRIX, *beta = NO_REAL_MATRIX;
   compute_pseudo_inverse (p, &mpinv, X, SMALL_EIGEN);
@@ -440,16 +440,16 @@ void genie_matrix_pls1 (NODE_T *p)
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
 // Pop arguments.
 // 'lim' is minimum relative length to first eigenvector.
-  A68_REAL lim;
-  POP_OBJECT (p, &lim, A68_REAL); 
+  A68G_REAL lim;
+  POP_OBJECT (p, &lim, A68G_REAL); 
 // 'Nc' is maximum number of eigenvectors.
-  A68_INT Nc;
-  POP_OBJECT (p, &Nc, A68_INT); 
-  A68_REF singulars;
+  A68G_INT Nc;
+  POP_OBJECT (p, &Nc, A68G_INT); 
+  A68G_REF singulars;
   POP_REF (p, &singulars);
 // X and Y matrices.
-  gsl_matrix *F = pop_matrix (p, A68_TRUE);
-  gsl_matrix *E = pop_matrix (p, A68_TRUE);
+  gsl_matrix *F = pop_matrix (p, A68G_TRUE);
+  gsl_matrix *E = pop_matrix (p, A68G_TRUE);
 // Catch wrong calls.
   unt Me = SIZE1 (E), Ne = SIZE2 (E), Mf = SIZE1 (F), Nf = SIZE2 (F);
   MATH_RTE (p, Mf == 0 || Nf == 0, M_ROW_ROW_REAL, "invalid column vector F");
@@ -465,7 +465,7 @@ void genie_matrix_pls1 (NODE_T *p)
 // Decompose E and F.
   gsl_matrix *EIGEN = NO_REAL_MATRIX, *nE = NO_REAL_MATRIX, *nF = NO_REAL_MATRIX; 
   gsl_vector *Sv = gsl_vector_calloc (Nk);
-  BOOL_T siga = A68_TRUE;
+  BOOL_T siga = A68G_TRUE;
   gsl_matrix *eigens = NO_REAL_MATRIX, *lat = NO_REAL_MATRIX, *pl = NO_REAL_MATRIX, *ql = NO_REAL_MATRIX;
   for (int k = 0; k < Nk && siga; k ++) {
 // E weight from E, F covariance.
@@ -474,7 +474,7 @@ void genie_matrix_pls1 (NODE_T *p)
     REAL_T norm = matrix_norm (eigens);
     if (k > 0 && (norm / gsl_vector_get (Sv, 0)) < VALUE (&lim)) {
       Nk = k;
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
     } else {
       ASSERT_GSL (gsl_matrix_scale (eigens, 1.0 / norm));
       gsl_vector_set (Sv, k, norm);
@@ -509,7 +509,7 @@ void genie_matrix_pls1 (NODE_T *p)
     for (int k = 0; k < Nk; k++) {
       gsl_vector_set (Svl, k, gsl_vector_get (Sv, k));
     }
-    *DEREF (A68_REF, &singulars) = vector_to_row (p, Svl);
+    *DEREF (A68G_REF, &singulars) = vector_to_row (p, Svl);
     a68g_vector_free (Svl);
   }
   push_matrix (p, beta);
@@ -543,16 +543,16 @@ void genie_matrix_pls2 (NODE_T *p)
   gsl_error_handler_t *save_handler = gsl_set_error_handler (torrix_error_handler);
 // Pop arguments.
 // 'lim' is minimum relative length to first eigenvector.
-  A68_REAL lim;
-  POP_OBJECT (p, &lim, A68_REAL); 
+  A68G_REAL lim;
+  POP_OBJECT (p, &lim, A68G_REAL); 
 // 'Nc' is maximum number of eigenvectors.
-  A68_INT Nc;
-  POP_OBJECT (p, &Nc, A68_INT); 
-  A68_REF singulars;
+  A68G_INT Nc;
+  POP_OBJECT (p, &Nc, A68G_INT); 
+  A68G_REF singulars;
   POP_REF (p, &singulars);
 // X and Y matrices.
-  gsl_matrix *F = pop_matrix (p, A68_TRUE);
-  gsl_matrix *E = pop_matrix (p, A68_TRUE);
+  gsl_matrix *F = pop_matrix (p, A68G_TRUE);
+  gsl_matrix *E = pop_matrix (p, A68G_TRUE);
 // Catch wrong calls.
   unt Me = SIZE1 (E), Ne = SIZE2 (E), Mf = SIZE1 (F), Nf = SIZE2 (F);
   MATH_RTE (p, Mf == 0 || Nf == 0, M_ROW_ROW_REAL, "invalid column vector F");
@@ -581,7 +581,7 @@ void genie_matrix_pls2 (NODE_T *p)
   gsl_matrix *eigens = NO_REAL_MATRIX;
   gsl_matrix *t = NO_REAL_MATRIX, *b = NO_REAL_MATRIX, *c = NO_REAL_MATRIX;
   gsl_matrix *pl = NO_REAL_MATRIX, *ql = NO_REAL_MATRIX, *nP = NO_REAL_MATRIX, *nC = NO_REAL_MATRIX;
-  BOOL_T siga = A68_TRUE;
+  BOOL_T siga = A68G_TRUE;
   for (int k = 0; k < Nk && siga; k ++) {
     REAL_T norm_e, norm;
     for (int j = 0; j < PLS_MAX_ITER; j ++) {
@@ -612,7 +612,7 @@ void genie_matrix_pls2 (NODE_T *p)
     }
     if (k > 0 && (norm_e / gsl_vector_get (Sv, 0)) < VALUE (&lim)) {
       Nk = k;
-      siga = A68_FALSE;
+      siga = A68G_FALSE;
     } else {
       gsl_vector_set (Sv, k, norm_e);
 // X factor loading and deflation.
@@ -649,7 +649,7 @@ void genie_matrix_pls2 (NODE_T *p)
     for (int k = 0; k < Nk; k++) {
       gsl_vector_set (Svl, k, gsl_vector_get (Sv, k));
     }
-    *DEREF (A68_REF, &singulars) = vector_to_row (p, Svl);
+    *DEREF (A68G_REF, &singulars) = vector_to_row (p, Svl);
     a68g_vector_free (Svl);
   }
   push_matrix (p, beta);
@@ -681,8 +681,8 @@ void genie_matrix_tls (NODE_T *p)
 {
 // TLS relates to PLS as OLS relates to PCR.
 // TLS is implemented as PLS1 with maximum number of singular values.
-  PUSH_VALUE (p, 0.0, A68_REAL);
-  PUSH_VALUE (p, 0, A68_INT);
+  PUSH_VALUE (p, 0.0, A68G_REAL);
+  PUSH_VALUE (p, 0, A68G_INT);
   genie_matrix_pls1 (p);
 }
 
