@@ -283,7 +283,7 @@ void op_ab_torrix (NODE_T * p, MOID_T * m, MOID_T * n, GPROC * op)
   if (IS_REF (m)) {
     genie_store (p, SUB (m), &dst, &src);
   } else {
-    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, __func__);
+    ABEND (A68G_TRUE, ERROR_INTERNAL_CONSISTENCY, NO_TEXT);
   }
   *save = dst;
 }
