@@ -89,7 +89,13 @@
 #define INSERTION_BLANK ((unt) 0x20)
 #define INSERTION_NORMAL ((unt) 0x10)
 
-#define MAX_RESTART 256
+// A68G_SIGALRM_INTERVAL in seconds between checks on elapsed execution time.
+#define A68G_SIGALRM_INTERVAL 5
+
+// MAX_INTERRUPT_RESTART after 'read' or 'write' are interrupted.
+// A68G_SIGALARM_INTERVAL * MAX_INTERRUPT_RESTART amounts to 600 seconds 
+// before IO times out due to SIGALRM interrupts with option NORESTART.
+#define MAX_INTERRUPT_RESTART 120
 
 #define A68G_DIR ".a68g"
 #define A68G_HISTORY_FILE ".a68g.edit.hist"
@@ -104,7 +110,6 @@
 #define EMBEDDED_FORMAT A68G_TRUE
 #define EVEN(k) ((k) % 2 == 0)
 #define HIDDEN_TEMP_FILE_NAME ".a68g.tmp"
-#define INTERRUPT_INTERVAL 5
 #define ITEM_NOT_USED (-1)
 #define MAX_ERRORS 5
 #define MAX_PRIORITY 9
@@ -496,6 +501,7 @@
 #define OPTION_REDUCTIONS(p) (OPTIONS (p).reductions)
 #define OPTION_REGRESSION_TEST(p) (OPTIONS (p).regression_test)
 #define OPTION_RERUN(p) (OPTIONS (p).rerun)
+#define OPTION_RESTART(p) (OPTIONS (p).restart)
 #define OPTION_RUN(p) (OPTIONS (p).run)
 #define OPTION_RUN_SCRIPT(p) (OPTIONS (p).run_script)
 #define OPTION_SOURCE_LISTING(p) (OPTIONS (p).source_listing)
