@@ -26,8 +26,6 @@
 #if !defined (__A68G_INCLUDES_H__)
 #define __A68G_INCLUDES_H__
 
-// Includes
-
 #if defined (HAVE_SYS_TYPES_H)
   #include <sys/types.h>
 #endif
@@ -153,9 +151,9 @@
   #include <strings.h>
 #endif
 
-#if (defined (HAVE_TERMIOS_H) && ! defined (TIOCGWINSZ))
+#if (defined (HAVE_TERMIOS_H) && !defined (TIOCGWINSZ))
   #include <termios.h>
-#elif (defined (HAVE_TERMIOS_H) && ! defined (GWINSZ_IN_SYS_IOCTL))
+#elif (defined (HAVE_TERMIOS_H) && !defined (GWINSZ_IN_SYS_IOCTL))
   #include <termios.h>
 #endif
 
@@ -282,7 +280,7 @@
 #endif
 
 #if defined (HAVE_REGEX_H)
-  #if defined (BUILD_WIN32) || defined (BUILD_WIN64)
+  #if defined (BUILD_WINDOWS)
     #include "a68g-regex.h"
   #else
     #include <regex.h>
@@ -290,7 +288,7 @@
 #endif
 
 #if defined (HAVE_LIBPQ_FE_H)
-  #if ! defined (A68G_OPTIMISE)
+  #if !defined (A68G_OPTIMISE)
     #include <libpq-fe.h>
   #endif
 #endif
