@@ -23,7 +23,7 @@
 //!
 //! Definitions for the plugin compiler.
 
-#if ! defined (__A68G_PLUGIN_H__)
+#if !defined (__A68G_PLUGIN_H__)
 #define __A68G_PLUGIN_H__
 
 typedef union UFU UFU;
@@ -139,7 +139,7 @@ void indentf (FILE_T, int);
 void indent (FILE_T, char *);
 void indent (FILE_T, char *);
 void init_static_frame (FILE_T, NODE_T *);
-void inline_arguments (NODE_T *, FILE_T, int, int *);
+void inline_arguments (NODE_T *, FILE_T, int, size_t *);
 void inline_call (NODE_T *, FILE_T, int);
 void inline_closed (NODE_T *, FILE_T, int);
 void inline_collateral (NODE_T *, FILE_T, int);
