@@ -45,63 +45,67 @@
 #define IS_NL_FF(ch) ((ch) == NEWLINE_CHAR || (ch) == FORMFEED_CHAR)
 
 #define A68G_MONAD(n, MODE, OP)\
-void n (NODE_T * p) {\
-  MODE *i;\
-  POP_OPERAND_ADDRESS (p, i, MODE);\
-  VALUE (i) = OP (VALUE (i));\
-}
+  void n (NODE_T * p) {\
+    MODE *i;\
+    POP_OPERAND_ADDRESS (p, i, MODE);\
+    VALUE (i) = OP (VALUE (i));\
+  }
 
 #if (A68G_LEVEL >= 3)
-GPROC genie_lt_bits;
-GPROC genie_gt_bits;
-DOUBLE_T mp_to_double (NODE_T *, MP_T *, int);
-MP_T *double_to_mp (NODE_T *, MP_T *, DOUBLE_T, int);
+  GPROC genie_lt_bits;
+  GPROC genie_gt_bits;
+  DOUBLE_T mp_to_double (NODE_T *, MP_T *, int);
+  MP_T *double_to_mp (NODE_T *, MP_T *, DOUBLE_T, int, BOOL_T, int);
+  MP_T *double_int_to_mp (NODE_T *, MP_T *, DOUBLE_NUM_T, int);
 #endif
 
-MOID_T *a68g_proc (MOID_T *, ...);
-void a68g_idf (BOOL_T, char *, MOID_T *, GPROC *);
-void a68g_prio (char *, int);
-void a68g_op (BOOL_T, char *, MOID_T *, GPROC *);
-void a68g_mode (int, char *, MOID_T **);
-A68G_REF c_string_to_row_char (NODE_T *, char *, int);
-A68G_REF c_to_a_string (NODE_T *, char *, int);
+A68G_REF c_string_to_row_char (NODE_T *, char *, size_t);
+A68G_REF c_to_a_string (NODE_T *, char *, size_t);
 A68G_REF empty_row (NODE_T *, MOID_T *);
 A68G_REF empty_string (NODE_T *);
 A68G_REF genie_make_row (NODE_T *, MOID_T *, int, ADDR_T);
 A68G_REF genie_store (NODE_T *, MOID_T *, A68G_REF *, A68G_REF *);
-A68G_REF heap_generator_2 (NODE_T *, MOID_T *, int, int);
-A68G_REF heap_generator_3 (NODE_T *, MOID_T *, int, int, int);
-A68G_REF heap_generator (NODE_T *, MOID_T *, int);
+A68G_REF heap_generator_2 (NODE_T *, MOID_T *, size_t, size_t);
+A68G_REF heap_generator_3 (NODE_T *, MOID_T *, size_t, size_t, size_t);
+A68G_REF heap_generator (NODE_T *, MOID_T *, size_t);
 A68G_REF tmp_to_a68g_string (NODE_T *, char *);
 ADDR_T calculate_internal_index (A68G_TUPLE *, int);
+BOOL_T a68g_finite_double (REAL_T);
+BOOL_T a68g_finite_real (REAL_T);
+BOOL_T a68g_isinf_double (REAL_T);
+BOOL_T a68g_isinf_real (REAL_T);
+BOOL_T a68g_isnan_double (REAL_T);
+BOOL_T a68g_isnan_real (REAL_T);
 BOOL_T close_device (NODE_T *, A68G_FILE *);
 BOOL_T genie_int_case_unit (NODE_T *, int, int *);
 BOOL_T increment_internal_index (A68G_TUPLE *, int);
 BOOL_T moid_needs_colouring (MOID_T *);
 char *a_to_c_string (NODE_T *, char *, A68G_REF);
-char *propagator_name (const PROP_PROC * p);
+char *propagator_name (PROP_PROC * p);
 FILE *a68g_fopen (char *, char *, char *);
 GPROC get_global_level;
 GPROC initialise_frame;
-int a68g_finite_real (REAL_T);
-int a68g_isinf_real (REAL_T);
-int a68g_isnan_real (REAL_T);
-int a68g_string_size (NODE_T *, A68G_REF);
 int char_value (int);
 int grep_in_string (char *, char *, int *, int *);
 INT_T a68g_round (REAL_T);
+MOID_T *a68g_proc (MOID_T *, ...);
 PROP_T genie_generator (NODE_T *);
 REAL_T seconds (void);
 REAL_T ten_up (int);
 REAL_T wall_seconds (void);
+size_t a68g_string_size (NODE_T *, A68G_REF);
+size_t heap_available (void);
 ssize_t io_read_conv (FILE_T, void *, size_t);
 ssize_t io_read (FILE_T, void *, size_t);
 ssize_t io_write_conv (FILE_T, const void *, size_t);
 ssize_t io_write (FILE_T, const void *, size_t);
-unt heap_available (void);
 void a68g_div_complex (A68G_REAL *, A68G_REAL *, A68G_REAL *);
 void a68g_exit (int);
 void a68g_exp_real_complex (A68G_REAL *, A68G_REAL *);
+void a68g_idf (BOOL_T, char *, MOID_T *, GPROC *);
+void a68g_mode (int, char *, MOID_T **);
+void a68g_op (BOOL_T, char *, MOID_T *, GPROC *);
+void a68g_prio (char *, int);
 void change_breakpoints (NODE_T *, unt, int, BOOL_T *, char *);
 void change_masks (NODE_T *, unt, BOOL_T);
 void colour_object (BYTE_T *, MOID_T *);
@@ -177,6 +181,7 @@ GPROC genie_add_real;
 GPROC genie_add_string;
 GPROC genie_and_bits;
 GPROC genie_and_bool;
+GPROC genie_append;
 GPROC genie_argc;
 GPROC genie_arg_complex;
 GPROC genie_argv;
@@ -353,6 +358,7 @@ GPROC genie_init_transput;
 GPROC genie_int_lengths;
 GPROC genie_int_shorths;
 GPROC genie_int_width;
+GPROC genie_inf;
 GPROC genie_inverfc_real;
 GPROC genie_inverf_real;
 GPROC genie_is_alnum;
@@ -433,6 +439,7 @@ GPROC genie_mul_complex;
 GPROC genie_mul_int;
 GPROC genie_mul_mp_int;
 GPROC genie_mul_real;
+GPROC genie_nan_real;
 GPROC genie_ne_bits;
 GPROC genie_ne_bool;
 GPROC genie_ne_bytes;
@@ -630,119 +637,120 @@ GPROC genie_xor_bits;
 GPROC genie_xor_bool;
 
 #if defined (S_ISFIFO)
-GPROC genie_file_is_fifo;
+  GPROC genie_file_is_fifo;
 #endif
 
 #if defined (S_ISLNK)
-GPROC genie_file_is_link;
+  GPROC genie_file_is_link;
 #endif
 
 #if defined (BUILD_PARALLEL_CLAUSE)
-GPROC genie_down_sema;
-GPROC genie_level_int_sema;
-GPROC genie_level_sema_int;
-GPROC genie_up_sema;
+  GPROC genie_down_sema;
+  GPROC genie_level_int_sema;
+  GPROC genie_level_sema_int;
+  GPROC genie_up_sema;
 #endif
 
 #if defined (HAVE_CURL)
-GPROC genie_http_content;
-GPROC genie_https_content;
+  GPROC genie_curl_timeout;
+  GPROC genie_http_content;
+  GPROC genie_https_content;
 #endif
 
 #if defined (HAVE_CURSES)
-GPROC genie_curses_clear;
-GPROC genie_curses_del_char;
-GPROC genie_curses_green;
-GPROC genie_curses_cyan;
-GPROC genie_curses_white;
-GPROC genie_curses_red;
-GPROC genie_curses_yellow;
-GPROC genie_curses_magenta;
-GPROC genie_curses_blue;
-GPROC genie_curses_green_inverse;
-GPROC genie_curses_cyan_inverse;
-GPROC genie_curses_white_inverse;
-GPROC genie_curses_red_inverse;
-GPROC genie_curses_yellow_inverse;
-GPROC genie_curses_magenta_inverse;
-GPROC genie_curses_blue_inverse;
-GPROC genie_curses_columns;
-GPROC genie_curses_end;
-GPROC genie_curses_getchar;
-GPROC genie_curses_lines;
-GPROC genie_curses_move;
-GPROC genie_curses_putchar;
-GPROC genie_curses_refresh;
-GPROC genie_curses_start;
+  GPROC genie_curses_clear;
+  GPROC genie_curses_del_char;
+  GPROC genie_curses_green;
+  GPROC genie_curses_cyan;
+  GPROC genie_curses_white;
+  GPROC genie_curses_red;
+  GPROC genie_curses_yellow;
+  GPROC genie_curses_magenta;
+  GPROC genie_curses_blue;
+  GPROC genie_curses_green_inverse;
+  GPROC genie_curses_cyan_inverse;
+  GPROC genie_curses_white_inverse;
+  GPROC genie_curses_red_inverse;
+  GPROC genie_curses_yellow_inverse;
+  GPROC genie_curses_magenta_inverse;
+  GPROC genie_curses_blue_inverse;
+  GPROC genie_curses_columns;
+  GPROC genie_curses_end;
+  GPROC genie_curses_getchar;
+  GPROC genie_curses_lines;
+  GPROC genie_curses_move;
+  GPROC genie_curses_putchar;
+  GPROC genie_curses_refresh;
+  GPROC genie_curses_start;
 #endif
 
 #if defined (HAVE_POSTGRESQL)
-GPROC genie_pq_backendpid;
-GPROC genie_pq_cmdstatus;
-GPROC genie_pq_cmdtuples;
-GPROC genie_pq_connectdb;
-GPROC genie_pq_db;
-GPROC genie_pq_errormessage;
-GPROC genie_pq_exec;
-GPROC genie_pq_fformat;
-GPROC genie_pq_finish;
-GPROC genie_pq_fname;
-GPROC genie_pq_fnumber;
-GPROC genie_pq_getisnull;
-GPROC genie_pq_getvalue;
-GPROC genie_pq_host;
-GPROC genie_pq_nfields;
-GPROC genie_pq_ntuples;
-GPROC genie_pq_options;
-GPROC genie_pq_parameterstatus;
-GPROC genie_pq_pass;
-GPROC genie_pq_port;
-GPROC genie_pq_protocolversion;
-GPROC genie_pq_reset;
-GPROC genie_pq_resulterrormessage;
-GPROC genie_pq_serverversion;
-GPROC genie_pq_socket;
-GPROC genie_pq_tty;
-GPROC genie_pq_user;
+  GPROC genie_pq_backendpid;
+  GPROC genie_pq_cmdstatus;
+  GPROC genie_pq_cmdtuples;
+  GPROC genie_pq_connectdb;
+  GPROC genie_pq_db;
+  GPROC genie_pq_errormessage;
+  GPROC genie_pq_exec;
+  GPROC genie_pq_fformat;
+  GPROC genie_pq_finish;
+  GPROC genie_pq_fname;
+  GPROC genie_pq_fnumber;
+  GPROC genie_pq_getisnull;
+  GPROC genie_pq_getvalue;
+  GPROC genie_pq_host;
+  GPROC genie_pq_nfields;
+  GPROC genie_pq_ntuples;
+  GPROC genie_pq_options;
+  GPROC genie_pq_parameterstatus;
+  GPROC genie_pq_pass;
+  GPROC genie_pq_port;
+  GPROC genie_pq_protocolversion;
+  GPROC genie_pq_reset;
+  GPROC genie_pq_resulterrormessage;
+  GPROC genie_pq_serverversion;
+  GPROC genie_pq_socket;
+  GPROC genie_pq_tty;
+  GPROC genie_pq_user;
 #endif
 
 #if defined (HAVE_GNU_PLOTUTILS)
-GPROC genie_draw_aspect;
-GPROC genie_draw_atom;
-GPROC genie_draw_background_colour;
-GPROC genie_draw_background_colour_name;
-GPROC genie_draw_circle;
-GPROC genie_draw_clear;
-GPROC genie_draw_colour;
-GPROC genie_draw_colour_name;
-GPROC genie_draw_fillstyle;
-GPROC genie_draw_fontname;
-GPROC genie_draw_fontsize;
-GPROC genie_draw_get_colour_name;
-GPROC genie_draw_line;
-GPROC genie_draw_linestyle;
-GPROC genie_draw_linewidth;
-GPROC genie_draw_move;
-GPROC genie_draw_point;
-GPROC genie_draw_rect;
-GPROC genie_draw_show;
-GPROC genie_draw_star;
-GPROC genie_draw_text;
-GPROC genie_draw_textangle;
-GPROC genie_make_device;
+  GPROC genie_draw_aspect;
+  GPROC genie_draw_atom;
+  GPROC genie_draw_background_colour;
+  GPROC genie_draw_background_colour_name;
+  GPROC genie_draw_circle;
+  GPROC genie_draw_clear;
+  GPROC genie_draw_colour;
+  GPROC genie_draw_colour_name;
+  GPROC genie_draw_fillstyle;
+  GPROC genie_draw_fontname;
+  GPROC genie_draw_fontsize;
+  GPROC genie_draw_get_colour_name;
+  GPROC genie_draw_line;
+  GPROC genie_draw_linestyle;
+  GPROC genie_draw_linewidth;
+  GPROC genie_draw_move;
+  GPROC genie_draw_point;
+  GPROC genie_draw_rect;
+  GPROC genie_draw_show;
+  GPROC genie_draw_star;
+  GPROC genie_draw_text;
+  GPROC genie_draw_textangle;
+  GPROC genie_make_device;
 #endif
 
 #if defined (BUILD_PARALLEL_CLAUSE)
-PROP_T genie_parallel (NODE_T *);
-BOOL_T is_main_thread (void);
-void genie_abend_all_threads (NODE_T *, jmp_buf *, NODE_T *);
-void genie_set_exit_from_threads (int);
-#define SAME_THREAD(p, q) (pthread_equal((p), (q)) != 0)
-#define OTHER_THREAD(p, q) (pthread_equal((p), (q)) == 0)
+  PROP_T genie_parallel (NODE_T *);
+  BOOL_T is_main_thread (void);
+  void genie_abend_all_threads (NODE_T *, jmp_buf *, NODE_T *);
+  void genie_set_exit_from_threads (int);
+  #define SAME_THREAD(p, q) (pthread_equal((p), (q)) != 0)
+  #define OTHER_THREAD(p, q) (pthread_equal((p), (q)) == 0)
 #endif
 
 #if defined (BUILD_LINUX)
-GPROC genie_sigsegv;
+  GPROC genie_sigsegv;
 #endif
 
 #endif
